@@ -1,4 +1,4 @@
-/* $Id: actions.cpp 16039 2007-02-24 16:31:54Z martinxyz $ */
+/* $Id: actions.cpp 16435 2007-03-27 15:11:30Z elias $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -712,8 +712,8 @@ void attack(display& gui, const gamemap& map,
 		LOG_NG << "firing attack event\n";
 		dat.add_child("first");
 		dat.add_child("second");
-		(*(dat.child("first")))["weapon"]=a_stats.weapon->name();
-		(*(dat.child("second")))["weapon"]=d_stats.weapon != NULL ? d_stats.weapon->name() : "none";
+		(*(dat.child("first")))["weapon"]=a_stats.weapon->id();
+		(*(dat.child("second")))["weapon"]=d_stats.weapon != NULL ? d_stats.weapon->id() : "none";
 		game_events::fire("attack",attacker,defender,dat);
 		//the event could have killed either the attacker or
 		//defender, so we have to make sure they still exist
@@ -730,8 +730,8 @@ void attack(display& gui, const gamemap& map,
 	dat.clear();
 	dat.add_child("first");
 	dat.add_child("second");
-	(*(dat.child("first")))["weapon"]=a_stats->weapon->name();
-	(*(dat.child("second")))["weapon"]=d_stats->weapon != NULL ? d_stats->weapon->name() : "none";
+	(*(dat.child("first")))["weapon"]=a_stats->weapon->id();
+	(*(dat.child("second")))["weapon"]=d_stats->weapon != NULL ? d_stats->weapon->id() : "none";
 
 	LOG_NG << "getting attack statistics\n";
 
@@ -1642,9 +1642,10 @@ void check_victory(unit_map& units,
 		if(non_interactive()) {
 			std::cout << "winner: ";
 			for(std::vector<int>::const_iterator i = seen_leaders.begin(); i != seen_leaders.end(); ++i) {
-				std::cout << *i << " ";
+				std::string ai = teams[*i - 1].ai_algorithm();
+				if (ai == "") ai = "default ai";
+				std::cout << *i << " (using " << ai << ") ";
 			}
-
 			std::cout << "\n";
 		}
 
