@@ -1,4 +1,4 @@
-/* $Id: ai.cpp 14607 2006-12-11 05:33:08Z sapient $ */
+/* $Id: ai.cpp 15917 2007-02-19 15:12:03Z torangan $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -335,18 +335,6 @@ void ai_interface::raise_user_interact()
 	last_interact_ = SDL_GetTicks();
 }
 
-void ai_interface::raise_unit_recruited(){
-	unit_recruited_.notify_observers();
-}
-
-void ai_interface::raise_unit_moved(){
-	unit_moved_.notify_observers();
-}
-
-void ai_interface::raise_enemy_attacked(){
-	enemy_attacked_.notify_observers();
-}
-
 void ai_interface::diagnostic(const std::string& msg)
 {
 	if(game_config::debug) {
@@ -361,15 +349,6 @@ void ai_interface::log_message(const std::string& msg)
 	}
 }
 
-team& ai_interface::current_team()
-{
-	return info_.teams[info_.team_num-1];
-}
-
-const team& ai_interface::current_team() const
-{
-	return info_.teams[info_.team_num-1];
-}
 
 gamemap::location ai_interface::move_unit(location from, location to, std::map<location,paths>& possible_moves)
 {
@@ -789,11 +768,6 @@ void ai::find_threats()
 	}
 }
 
-void ai::add_target(const target& tgt)
-{
-	additional_targets_.push_back(tgt);
-}
-
 void ai::play_turn()
 {
 	consider_combat_ = true;
@@ -2035,11 +2009,6 @@ const ai::defensive_position& ai::best_defensive_position(const gamemap::locatio
 	return defensive_position_cache_[loc];
 }
 
-void ai::invalidate_defensive_position_cache()
-{
-	defensive_position_cache_.clear();
-}
-
 bool ai::is_accessible(const location& loc, const move_map& dstsrc) const
 {
 	gamemap::location adj[6];
