@@ -1,4 +1,4 @@
-/* $Id: ai.hpp 12045 2006-06-11 20:32:40Z sapient $ */
+/* $Id: ai.hpp 15917 2007-02-19 15:12:03Z torangan $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -46,7 +46,7 @@ public:
 	defensive_position const& best_defensive_position(const location& unit,
 			const move_map& dstsrc, const move_map& srcdst, const move_map& enemy_dstsrc) const;
 
-	void invalidate_defensive_position_cache();
+	void invalidate_defensive_position_cache() { defensive_position_cache_.clear(); }
 
 	bool leader_can_reach_keep() const;
 
@@ -219,7 +219,7 @@ protected:
 	bool consider_combat_;
 	std::vector<target> additional_targets_;
 
-	void add_target(const target& tgt);
+	void add_target(const target& tgt) { additional_targets_.push_back(tgt); }
 
 	//function which will analyze all the units that this side can recruit and rate
 	//their movement types. Ratings will be placed in 'unit_movement_scores_', with
