@@ -1,4 +1,4 @@
-/* $Id: ai_attack.cpp 12639 2006-07-19 11:54:19Z rusty $ */
+/* $Id: ai_attack.cpp 13988 2006-10-16 01:58:47Z rusty $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -152,17 +152,19 @@ void ai::do_attack_analysis(
 			}
 
 			//see if the current unit can reach that position
-			typedef std::multimap<location,location>::const_iterator Itor;
-			std::pair<Itor,Itor> its = dstsrc.equal_range(tiles[j]);
-			while(its.first != its.second) {
-				if(its.first->second == current_unit)
-					break;
-				++its.first;
-			}
+			if (tiles[j] != current_unit) {
+				typedef std::multimap<location,location>::const_iterator Itor;
+				std::pair<Itor,Itor> its = dstsrc.equal_range(tiles[j]);
+				while(its.first != its.second) {
+					if(its.first->second == current_unit)
+						break;
+					++its.first;
+				}
 
-			//if the unit can't move to this location
-			if(its.first == its.second || units_.find(tiles[j]) != units_.end()) {
-				continue;
+				//if the unit can't move to this location
+				if(its.first == its.second || units_.find(tiles[j]) != units_.end()) {
+					continue;
+				}
 			}
 
 			//check to see whether this move would be a backstab
@@ -362,7 +364,7 @@ void ai::attack_analysis::analyze(const gamemap& map, unit_map& units,
 			from_cache = true;
 			bc = new battle_context(usc->second.first, usc->second.second);
 		} else {
-			bc = new battle_context(map, teams, units, status, gamedata, m->second, target, att_weapon, def_weapon, 1.0 - aggression, prev_def);
+			bc = new battle_context(map, teams, units, status, gamedata, m->second, target, att_weapon, def_weapon, aggression, prev_def);
 		}
 		const combatant &att = bc->get_attacker_combatant(prev_def);
 		const combatant &def = bc->get_defender_combatant(prev_def);
@@ -552,7 +554,7 @@ std::vector<ai::attack_analysis> ai::analyze_targets(
 
 	std::vector<location> unit_locs;
 	for(unit_map::const_iterator i = units_.begin(); i != units_.end(); ++i) {
-		if(i->second.side() == team_num_) {
+		if(i->second.side() == team_num_ && i->second.attacks_left()) {
 			unit_locs.push_back(i->first);
 		}
 	}
