@@ -1,6 +1,6 @@
-/* $Id: ai_move.cpp,v 1.62 2005/06/04 19:16:05 ott Exp $ */
+/* $Id: ai_move.cpp 11677 2006-05-28 11:57:45Z rusty $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -33,11 +33,11 @@ struct move_cost_calculator : cost_calculator
 						 const ai::move_map& dstsrc,
 						 const ai::move_map& enemy_dstsrc)
 	  : unit_(u), map_(map), data_(data), units_(units),
-	    move_type_(u.type().movement_type()), loc_(loc), dstsrc_(dstsrc), enemy_dstsrc_(enemy_dstsrc),
-		avoid_enemies_(u.type().usage() == "scout")
+	    loc_(loc), dstsrc_(dstsrc), enemy_dstsrc_(enemy_dstsrc),
+		avoid_enemies_(u.usage() == "scout")
 	{}
 
-	virtual double cost(const gamemap::location& loc, const double, const bool) const
+	virtual double cost(const gamemap::location&, const gamemap::location& loc, const double, const bool) const
 	{
 		/*
 		if(!map_.on_board(loc))
@@ -58,7 +58,7 @@ struct move_cost_calculator : cost_calculator
 		const gamemap::TERRAIN terrain = map_[loc.x][loc.y];
 
 		const double modifier = 1.0; //move_type_.defense_modifier(map_,terrain);
-		const double move_cost = move_type_.movement_cost(map_,terrain);
+		const double move_cost = unit_.movement_cost(terrain);//move_type_[terrain];
 
 		const int enemies = 1 + (avoid_enemies_ ? enemy_dstsrc_.count(loc) : 0);
 		double res = modifier*move_cost*double(enemies);
@@ -77,13 +77,13 @@ private:
 	const gamemap& map_;
 	const game_data& data_;
 	const unit_map& units_;
-	const unit_movement_type& move_type_;
+//	mutable std::map<gamemap::TERRAIN,int> move_type_;
 	const gamemap::location loc_;
 	const ai::move_map dstsrc_, enemy_dstsrc_;
 	const bool avoid_enemies_;
 };
 
-std::vector<ai::target> ai::find_targets(unit_map::const_iterator leader, const move_map& enemy_srcdst, const move_map& enemy_dstsrc)
+std::vector<ai::target> ai::find_targets(unit_map::const_iterator leader, const move_map& enemy_dstsrc)
 {
 	log_scope2(ai, "finding targets...");
 
@@ -93,7 +93,7 @@ std::vector<ai::target> ai::find_targets(unit_map::const_iterator leader, const
 
 	//if enemy units are in range of the leader, then we target the enemies who are in range.
 	if(has_leader) {
-		const double threat = power_projection(leader->first,enemy_srcdst,enemy_dstsrc);
+		const double threat = power_projection(leader->first,enemy_dstsrc);
 		if(threat > 0.0) {
 			//find the location of enemy threats
 			std::set<gamemap::location> threats;
@@ -153,7 +153,7 @@ std::vector<ai::target> ai::find_targets(unit_map::const_iterator leader, const
 		//explicit targets for this team
 		for(std::vector<team::target>::iterator j = team_targets.begin();
 		    j != team_targets.end(); ++j) {
-			if(u->second.matches_filter(j->criteria)) {
+			if(u->second.matches_filter(j->criteria,u->first)) {
 				LOG_AI << "found explicit target..." << j->value << "\n";
 				targets.push_back(target(u->first,j->value,target::EXPLICIT));
 			}
@@ -187,7 +187,7 @@ std::vector<ai::target> ai::find_targets(unit_map::const_iterator leader, const
 	return targets;
 }
 
-gamemap::location ai::form_group(const std::vector<location>& route, const move_map& dstsrc, const move_map& srcdst, std::set<location>& res)
+gamemap::location ai::form_group(const std::vector<location>& route, const move_map& dstsrc, std::set<location>& res)
 {
 	if(route.empty()) {
 		return location();
@@ -228,7 +228,7 @@ gamemap::location ai::form_group(const std::vector<location>& route, const move_
 	return *i;
 }
 
-void ai::enemies_along_path(const std::vector<location>& route, const move_map& dstsrc, const move_map& srcdst, std::set<location>& res)
+void ai::enemies_along_path(const std::vector<location>& route, const move_map& dstsrc, std::set<location>& res)
 {
 	for(std::vector<location>::const_iterator i = route.begin(); i != route.end(); ++i) {
 		gamemap::location adj[6];
@@ -303,7 +303,7 @@ bool ai::move_group(const location& dst, const std::vector<location>& route, con
 				continue;
 			}
 
-			const int defense = un->second.defense_modifier(map_,map_.get_terrain(*j));
+			const int defense = un->second.defense_modifier(map_.get_terrain(*j));
 			if(best_loc.valid() == false || defense < best_defense) {
 				best_loc = *j;
 				best_defense = defense;
@@ -352,7 +352,7 @@ double ai::rate_group(const std::set<location>& group, const std::vector<locatio
 
 		int defense = 0;
 		for(std::vector<location>::const_iterator j = battlefield.begin(); j != battlefield.end(); ++j) {
-			defense += un.defense_modifier(map_,map_.get_terrain(*j));
+			defense += un.defense_modifier(map_.get_terrain(*j));
 		}
 
 		defense /= battlefield.size();
@@ -378,11 +378,11 @@ double ai::compare_groups(const std::set<location>& our_group, const std::set<lo
 	return a/b;
 }
 
-std::pair<gamemap::location,gamemap::location> ai::choose_move(std::vector<target>& targets, const move_map& srcdst, const move_map& dstsrc, const move_map& enemy_srcdst, const move_map& enemy_dstsrc)
+std::pair<gamemap::location,gamemap::location> ai::choose_move(std::vector<target>& targets, const move_map& srcdst, const move_map& dstsrc, const move_map& enemy_dstsrc)
 {
 	log_scope2(ai, "choosing move");
 
-	user_interact();
+	raise_user_interact();
 
 	std::vector<target>::const_iterator ittg;
 	for(ittg = targets.begin(); ittg != targets.end(); ++ittg) {
@@ -392,6 +392,7 @@ std::pair<gamemap::location,gamemap::location> ai::choose_move(std::vector<targe
 	paths::route best_route;
 	unit_map::iterator best = units_.end();
 	double best_rating = 0.1;
+
 	std::vector<target>::iterator best_target = targets.end();
 
 	unit_map::iterator u;
@@ -409,8 +410,8 @@ std::pair<gamemap::location,gamemap::location> ai::choose_move(std::vector<targe
 	}
 
 	//guardian units stay put
-	if(u->second.is_guardian()) {
-		LOG_AI << u->second.type().id() << " is guardian, staying still\n";
+	if(utils::string_bool(u->second.get_state("guardian"))) {
+		LOG_AI << u->second.id() << " is guardian, staying still\n";
 		return std::pair<location,location>(u->first,u->first);
 	}
 
@@ -422,9 +423,10 @@ std::pair<gamemap::location,gamemap::location> ai::choose_move(std::vector<targe
 			continue;
 		}
 
-		user_interact();
+		raise_user_interact();
 
 		wassert(map_.on_board(tg->loc));
+
 		const double locStopValue = minimum(tg->value / best_rating, 500.0);
 		paths::route cur_route = a_star_search(u->first, tg->loc, locStopValue, &cost_calc, map_.x(), map_.y());
 
@@ -454,9 +456,9 @@ std::pair<gamemap::location,gamemap::location> ai::choose_move(std::vector<targe
 		}
 
 		//scouts do not like encountering enemies on their paths
-		if(u->second.type().usage() == "scout") {
+		if(u->second.usage() == "scout") {
 			std::set<location> enemies_guarding;
-			enemies_along_path(cur_route.steps,enemy_dstsrc,enemy_srcdst,enemies_guarding);
+			enemies_along_path(cur_route.steps,enemy_dstsrc,enemies_guarding);
 
 			if(enemies_guarding.size() > 1) {
 				rating /= enemies_guarding.size();
@@ -479,6 +481,10 @@ std::pair<gamemap::location,gamemap::location> ai::choose_move(std::vector<targe
 			best_target = tg;
 			best = u;
 			best_route = cur_route;
+			if(best_rating == 0)
+			{
+				best_rating = 0.000000001; //prevent divivion by zero
+			}
 		}
 	}
 
@@ -492,18 +498,18 @@ std::pair<gamemap::location,gamemap::location> ai::choose_move(std::vector<targe
 
 	//if we have the 'simple_targetting' flag set, then we don't see if any other
 	//units can put a better bid forward for this target
-	const bool dumb_ai = current_team().ai_parameters()["simple_targetting"] == "yes";
+	const bool dumb_ai = utils::string_bool(current_team().ai_parameters()["simple_targetting"]);
 
 	if(dumb_ai == false) {
 		LOG_AI << "complex targetting...\n";
 		//now see if any other unit can put a better bid forward
 		for(++u; u != units_.end(); ++u) {
 			if(u->second.side() != team_num_ || u->second.can_recruit() ||
-			   u->second.movement_left() <= 0 || u->second.is_guardian() || u->second.incapacitated()) {
+			   u->second.movement_left() <= 0 || utils::string_bool(u->second.get_state("guardian")) || u->second.incapacitated()) {
 				continue;
 			}
 
-			user_interact();
+			raise_user_interact();
 
 			const move_cost_calculator calc(u->second, map_, gameinfo_, units_, u->first, dstsrc, enemy_dstsrc);
 			const double locStopValue = minimum(best_target->value / best_rating, 100.0);
@@ -535,9 +541,9 @@ std::pair<gamemap::location,gamemap::location> ai::choose_move(std::vector<targe
 			}
 
 			//scouts do not like encountering enemies on their paths
-			if(u->second.type().usage() == "scout") {
+			if(u->second.usage() == "scout") {
 				std::set<location> enemies_guarding;
-				enemies_along_path(cur_route.steps,enemy_dstsrc,enemy_srcdst,enemies_guarding);
+				enemies_along_path(cur_route.steps,enemy_dstsrc,enemies_guarding);
 
 				if(enemies_guarding.size() > 1) {
 					rating /= enemies_guarding.size();
@@ -583,8 +589,8 @@ std::pair<gamemap::location,gamemap::location> ai::choose_move(std::vector<targe
 
 			for(std::vector<location>::const_iterator i = locs.begin(); i != locs.end(); ++i) {
 				const int distance = distance_between(*i,best_target->loc);
-				const int defense = best->second.defense_modifier(map_,map_.get_terrain(*i));
-				const double vulnerability = power_projection(*i,enemy_srcdst,enemy_dstsrc);
+				const int defense = best->second.defense_modifier(map_.get_terrain(*i));
+				const double vulnerability = power_projection(*i,enemy_dstsrc);
 
 				if(best_loc.valid() == false || defense < best_defense || defense == best_defense && vulnerability < best_vulnerability) {
 					best_loc = *i;
@@ -618,15 +624,15 @@ std::pair<gamemap::location,gamemap::location> ai::choose_move(std::vector<targe
 		//if any point along the path is too dangerous for our single unit, then we hold back
 		for(std::vector<location>::const_iterator i = best_route.steps.begin(); i != best_route.steps.end() && movement > 0; ++i) {
 
-			const double threat = power_projection(*i,enemy_srcdst,enemy_dstsrc);
-			if(threat >= double(best->second.hitpoints()) && threat > power_projection(*i,fullmove_srcdst,fullmove_dstsrc) ||
+			const double threat = power_projection(*i,enemy_dstsrc);
+			if(threat >= double(best->second.hitpoints()) && threat > power_projection(*i,fullmove_dstsrc) ||
 			   i >= best_route.steps.end()-2 && unit_at_target != units_.end() && current_team().is_enemy(unit_at_target->second.side())) {
 				dangerous = true;
 				break;
 			}
 
 			if(!defensive_grouping) {
-				movement -= best->second.movement_cost(map_,map_.get_terrain(*i));
+				movement -= best->second.movement_cost(map_.get_terrain(*i));
 			}
 		}
 
@@ -636,8 +642,8 @@ std::pair<gamemap::location,gamemap::location> ai::choose_move(std::vector<targe
 	if(dangerous) {
 		LOG_AI << "dangerous path\n";
 		std::set<location> group, enemies;
-		const location dst = form_group(best_route.steps,dstsrc,srcdst,group);
-		enemies_along_path(best_route.steps,enemy_dstsrc,enemy_srcdst,enemies);
+		const location dst = form_group(best_route.steps,dstsrc,group);
+		enemies_along_path(best_route.steps,enemy_dstsrc,enemies);
 
 		const double our_strength = compare_groups(group,enemies,best_route.steps);
 
@@ -676,8 +682,8 @@ std::pair<gamemap::location,gamemap::location> ai::choose_move(std::vector<targe
 			const std::pair<move_map::const_iterator,move_map::const_iterator> itors = srcdst.equal_range(loc);
 			for(move_map::const_iterator i = itors.first; i != itors.second; ++i) {
 				const int distance = distance_between(target_loc,i->second);
-				const int defense = un.defense_modifier(map_,map_.get_terrain(i->second));
-				const double threat = (power_projection(i->second,enemy_srcdst,enemy_dstsrc)*defense)/100;
+				const int defense = un.defense_modifier(map_.get_terrain(i->second));
+				const double threat = (power_projection(i->second,enemy_dstsrc)*defense)/100;
 
 				if(best_loc.valid() == false || threat < maximum<double>(best_threat,max_acceptable_threat) && distance < best_distance) {
 					best_loc = i->second;
@@ -715,8 +721,9 @@ std::pair<gamemap::location,gamemap::location> ai::choose_move(std::vector<targe
 		std::pair<Itor,Itor> its = dstsrc.equal_range(*ri);
 		while(its.first != its.second) {
 			if(its.first->second == best->first) {
-				if(!should_retreat(its.first->first,best,fullmove_srcdst,fullmove_dstsrc,enemy_srcdst,enemy_dstsrc)) {
-					const double value = best_target->value - best->second.type().cost()/20.0;
+				if(!should_retreat(its.first->first,best,fullmove_srcdst,fullmove_dstsrc,enemy_dstsrc,
+								   current_team().caution())) {
+					const double value = best_target->value - best->second.cost()/20.0;
 
 					if(value > 0.0 && best_target->type != target::MASS) {
 						//there are enemies ahead. Rally troops around us to
@@ -763,14 +770,13 @@ void ai::access_points(const move_map& srcdst, const location& u, const location
 		return;
 	}
 
-	unit_map single_unit;
-	single_unit.insert(*u_it);
+	unit_map single_unit(u_it->first, u_it->second);
 
 	const std::pair<move_map::const_iterator,move_map::const_iterator> locs = srcdst.equal_range(u);
 	for(move_map::const_iterator i = locs.first; i != locs.second; ++i) {
 		const location& loc = i->second;
 		if (int(distance_between(loc,dst)) <= u_it->second.total_movement()) {
-			shortest_path_calculator calc(u_it->second, current_team(), units_, teams_, map_, state_);
+			shortest_path_calculator calc(u_it->second, current_team(), units_, teams_, map_);
 			const paths::route& rt = a_star_search(loc, dst, u_it->second.total_movement(), &calc, map_.x(), map_.y());
 			if(rt.steps.empty() == false) {
 				out.push_back(loc);
