@@ -180,8 +180,13 @@ prob_matrix::prob_matrix(unsigned int a_max_hp, unsigned int b_max_hp,
 		}
 		debug(("B has fought before\n"));
 		dump();
-	} else
+	} else {
+		// if a unit has drain it might end with more HP than before
+		// make sure we don't access the matrix in invalid positions
+		a_hp = minimum<unsigned int>(a_hp, rows - 1);
+		b_hp = minimum<unsigned int>(b_hp, cols - 1);
 		val(NEITHER_SLOWED, a_hp, b_hp) = 1.0;
+	}
 }
 
 prob_matrix::~prob_matrix()
@@ -531,7 +536,10 @@ void combatant::adjust_hitchance()
 
 	unsigned int i;
 	for (i = 1; i <= u_.max_hp; i++) {
-		double prob = summary[0][i];
+		double prob = 0.0;
+		if(i < summary[0].size()) {
+			prob = summary[0][i];
+		}
 		if (!summary[1].empty())
 			prob += summary[1][i];
 		for (unsigned int j = 0; j < u_.swarm_min + (u_.swarm_max - (double)u_.swarm_min) * u_.hp / u_.max_hp; j++)
@@ -779,9 +787,14 @@ void combatant::fight(combatant &opp)
 			opp.hp_dist[i] = opp.summary[0][i] + opp.summary[1][i];
 	}
 
+	// make sure we don't try to access the vectors out of bounds, drain increases hps
+	// so we determine the number of hp here and make sure it stays within bounds
+	const unsigned int hp = minimum<unsigned int>(u_.hp, hp_dist.size() - 1);
+	const unsigned int opp_hp = minimum<unsigned int>(opp.u_.hp, opp.hp_dist.size() - 1);
+
 	// Chance that we / they were touched this time.
-	double touched = untouched - hp_dist[u_.hp];
-	double opp_touched = opp.untouched - opp.hp_dist[opp.u_.hp];
+	double touched = untouched - hp_dist[hp];
+	double opp_touched = opp.untouched - opp.hp_dist[opp_hp];
 	if (opp.u_.poisons)
 		poisoned += (1 - poisoned) * touched;
 	if (u_.poisons)
@@ -793,8 +806,8 @@ void combatant::fight(combatant &opp)
 		opp.slowed += (1 - opp.slowed) * opp_touched;
 
 	// FIXME: This is approximate: we could drain, then get hit.
-	untouched = hp_dist[u_.hp];
-	opp.untouched = opp.hp_dist[opp.u_.hp];
+	untouched = hp_dist[hp];
+	opp.untouched = opp.hp_dist[opp_hp];
 }
 
 double combatant::average_hp(unsigned int healing) const
