@@ -1,4 +1,4 @@
-/* $Id: config.hpp 11877 2006-06-05 20:02:25Z soliton $ */
+/* $Id: config.hpp 13223 2006-08-26 17:44:23Z dirus $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -125,6 +125,9 @@ public:
 
 	config merge_with(const config& c) const;
 
+	//removes keys with empty values
+	void prune();
+
 	//append data from another config object to this one. attributes in the
 	//latter config object will clobber attributes in this one.
 	void append(const config& cfg);
@@ -140,6 +143,9 @@ public:
 	string_map values;
 
 private:
+	//detach child nodes without deleting them (eg. for moving)
+	void detach_children(const std::string& key);
+
 	//a list of all children of this node.
 	child_map children;
 
