@@ -41,7 +41,7 @@ std::string get_unique_saveid(const config& cfg, std::set<std::string>& seen_sav
 	return save_id;
 }
 
-void get_player_info(const config& cfg, game_state& gamestate, std::string save_id, std::vector<team>& teams, const config& level, const game_data& gameinfo, gamemap& map, unit_map& units, gamestatus& game_status){
+void get_player_info(const config& cfg, game_state& gamestate, std::string save_id, std::vector<team>& teams, const config& level, const game_data& gameinfo, gamemap& map, unit_map& units, gamestatus& game_status, bool snapshot){
 	player_info *player = NULL;
 
 	if(cfg["controller"] == "human" ||
@@ -63,7 +63,7 @@ void get_player_info(const config& cfg, game_state& gamestate, std::string save_
 	LOG_NG << "found gold: '" << gold << "'\n";
 
 	int ngold = lexical_cast_default<int>(gold);
-	if(player != NULL && player->gold >= ngold) {
+	if ( (player != NULL) && (player->gold >= ngold) && (!snapshot) ) {
 		ngold = player->gold;
 	}
 
@@ -141,7 +141,15 @@ void get_player_info(const config& cfg, game_state& gamestate, std::string save_
 
 	//if there are additional starting units on this side
 	const config::child_list& starting_units = cfg.get_children("unit");
-	if ( (starting_units.begin() != starting_units.end()) && (player) ){
+	//available_units has been filled by loading the [player]-section already. However, we need
+	//to get the information from the snapshot so we start from scratch here. This is rather a
+	//quick hack, originating from keeping changes as minimal as possible for 1.2. Moving [player]
+	//into [replay_start] should be the correct way to go.
+	if (player && snapshot){
+		player->available_units.clear();
+	}
+	//backwards compatibility code for 1.2/1.2.1
+	if ( (starting_units.begin() != starting_units.end()) && player && (!gamestate.version.empty()) && (gamestate.version < "1.2.2") ){
 		player->available_units.clear();
 	}
 	for(config::child_list::const_iterator su = starting_units.begin(); su != starting_units.end(); ++su) {
