@@ -1,9 +1,22 @@
+/* $Id: cursor.cpp 9702 2006-01-15 13:03:14Z j_daniel $ */
+/*
+   Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
+   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY.
+
+   See the COPYING file for more details.
+*/
+
 #include "global.hpp"
 
 #include "cursor.hpp"
 #include "game_config.hpp"
 #include "image.hpp"
-#include "preferences.hpp"
+#include "preferences_display.hpp"
 #include "scoped_resource.hpp"
 #include "sdl_utils.hpp"
 #include "video.hpp"
@@ -29,11 +42,15 @@ SDL_Cursor* create_cursor(surface surf)
 	}
 
 	//the width must be a multiple of 8 (SDL requirement)
+
+#ifdef __APPLE__
+	size_t cursor_width = 16;
+#else
 	size_t cursor_width = nsurf->w;
 	if((cursor_width%8) != 0) {
 		cursor_width += 8 - (cursor_width%8);
 	}
-
+#endif
 	std::vector<Uint8> data((cursor_width*nsurf->h)/8,0);
 	std::vector<Uint8> mask(data.size(),0);
 
@@ -41,20 +58,27 @@ SDL_Cursor* create_cursor(surface surf)
 	//the format that data has to be in to pass to SDL_CreateCursor
 	surface_lock lock(nsurf);
 	const Uint32* const pixels = reinterpret_cast<Uint32*>(lock.pixels());
-	for(size_t y = 0; y != nsurf->h; ++y) {
-		for(size_t x = 0; x != nsurf->w; ++x) {
+	for(int y = 0; y != nsurf->h; ++y) {
+		for(int x = 0; x != nsurf->w; ++x) {
 			Uint8 r,g,b,a;
-			SDL_GetRGBA(pixels[y*nsurf->w + x],nsurf->format,&r,&g,&b,&a);
+			Uint8 trans = 0;
+			Uint8 black = 0;
 
 			const size_t index = y*cursor_width + x;
 
-			const size_t shift = 7 - (index%8);
+			if ((size_t)x < cursor_width) {
+				SDL_GetRGBA(pixels[y*nsurf->w + x],nsurf->format,&r,&g,&b,&a);
+
+				const size_t shift = 7 - (index%8);
+
+				trans = (a < 128 ? 0 : 1) << shift;
+				black = (trans == 0 || (r+g+b)/3 > 128 ? 0 : 1) << shift;
+
+				data[index/8] |= black;
+				mask[index/8] |= trans;
+			}
 
-			const Uint8 trans = (a < 128 ? 0 : 1) << shift;
-			const Uint8 black = (trans == 0 || (r+g+b)/3 > 128 ? 0 : 1) << shift;
 
-			data[index/8] |= black;
-			mask[index/8] |= trans;
 		}
 	}
 
@@ -64,7 +88,11 @@ SDL_Cursor* create_cursor(surface surf)
 SDL_Cursor* cache[cursor::NUM_CURSORS] = { NULL, NULL, NULL, NULL };
 
 //this array must have members corresponding to cursor::CURSOR_TYPE enum members
+#ifdef __APPLE__
+const std::string images[cursor::NUM_CURSORS] = { "normal.png", "wait-alt.png", "move.png", "attack.png", "select.png" };
+#else
 const std::string images[cursor::NUM_CURSORS] = { "normal.png", "wait.png", "move.png", "attack.png", "select.png" };
+#endif
 
 cursor::CURSOR_TYPE current_cursor = cursor::NUM_CURSORS;
 
