@@ -1,4 +1,4 @@
-/* $Id: dialogs.cpp 12768 2006-07-25 16:32:50Z jhinrichs $ */
+/* $Id: dialogs.cpp 13625 2006-09-21 22:58:13Z edb $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -138,7 +138,7 @@ bool animate_unit_advancement(const game_data& info,unit_map& units, gamemap::lo
 			gui.invalidate(loc);
 			gui.draw();
 			events::pump();
-			gui.non_turbo_delay();
+			gui.delay(10);
 		}
 	}
 
@@ -161,7 +161,7 @@ bool animate_unit_advancement(const game_data& info,unit_map& units, gamemap::lo
 			gui.invalidate(loc);
 			gui.draw();
 			events::pump();
-			gui.non_turbo_delay();
+			gui.delay(10);
 		}
 		u->second.set_standing(gui,u->first);
 		gui.invalidate(loc);
@@ -295,8 +295,12 @@ void save_preview_pane::draw_contents()
 	std::string dummy;
 	config& summary = *(*summaries_)[index_];
 	if (summary["label"] == ""){
-		load_game_summary((*info_)[index_].name, summary, &dummy);
-		*(*summaries_)[index_] = summary;
+		try {
+			load_game_summary((*info_)[index_].name, summary, &dummy);
+			*(*summaries_)[index_] = summary;
+		} catch(game::load_game_failed&) {
+			summary["corrupt"] = "yes";
+		}
 	}
 
 	surface const screen = video().getSurface();
