@@ -1,4 +1,4 @@
-/* $Id: display.cpp 16280 2007-03-18 15:42:04Z mordante $ */
+/* $Id: display.cpp 20786 2007-10-01 11:26:25Z mordante $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -2356,7 +2356,15 @@ void display::add_chat_message(const std::string& speaker, int side, const std::
 			msg = message;
 			action = false;
 		}
-		msg = font::word_wrap_text(msg,font::SIZE_SMALL,mapx()*3/4);
+
+		try {
+			// We've had a joker who send an invalid utf-8 message to crash clients
+			// so now catch the exception and ignore the message.
+			msg = font::word_wrap_text(msg,font::SIZE_SMALL,mapx()*3/4);
+		} catch (utils::invalid_utf8_exception&) {
+			LOG_STREAM(err, engine) << "Invalid utf-8 found, chat message is ignored.\n";
+			return;
+		}
 
 		int ypos = chat_message_x;
 		for(std::vector<chat_message>::const_iterator m = chat_messages_.begin(); m != chat_messages_.end(); ++m) {
