@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+  Copyright (C) 2003 by David White <davidnwhite@verizon.net>
   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
   This program is free software; you can redistribute it and/or modify
@@ -12,15 +12,23 @@
 #ifndef EDITOR_H_INCLUDED
 #define EDITOR_H_INCLUDED
 
+#include "global.hpp"
+
+#include "SDL.h"
+
 #include "editor_palettes.hpp"
 #include "editor_layout.hpp"
 #include "editor_undo.hpp"
 
 #include "../display.hpp"
 #include "../events.hpp"
+#include "../font.hpp"
 #include "../hotkeys.hpp"
-#include "../preferences.hpp"
+#include "../preferences_display.hpp"
 #include "../theme.hpp"
+#include "../tooltips.hpp"
+//#include "gui/key_listener.hpp"
+//#include "gui/mouse_listener.hpp"
 
 #include <map>
 #include <queue>
@@ -89,6 +97,9 @@ public:
 	/// Recalculate layout and redraw everything.
 	void redraw_everything();
 
+	// Change the language in_game
+	virtual void change_language();
+
 	// Methods inherited from command_executor. Used to perform
 	// operations on menu/hotkey commands.
 	virtual void toggle_grid();
@@ -168,6 +179,9 @@ private:
 	/// given.
 	void set_starting_position(const int player, const gamemap::location loc);
 
+	/// Check whether the filename contains illegal characters.
+	bool verify_filename(const std::string& filename, bool show_error) const;
+
 	/// Display a menu with given items and at the given location.
 	void show_menu(const std::vector<std::string>& items_arg, const int xloc,
 				   const int yloc, const bool context_menu=false);
@@ -270,6 +284,9 @@ private:
 	/// for brush size.
 	void draw_on_mouseover_hexes(const gamemap::TERRAIN t);
 
+	// Load the tooltips for each button
+	void load_tooltips(void);
+
 	/// An item in the clipboard. Consists of the copied terrain and an
 	/// offset. When pasting stuff, the offset is used to calculate
 	/// where to put the pasted hex when calculating from the one
@@ -311,6 +328,9 @@ private:
 	gamemap::location clipboard_offset_loc_;
 	LEFT_BUTTON_HELD_FUNC l_button_held_func_;
 	gamemap::location selection_move_start_;
+
+	tooltips::manager tooltip_manager_;
+	font::floating_label_context floating_label_manager_;
 	// mouse_moved_ will be true if the mouse have moved between two
 	// cycles.
 	bool mouse_moved_;
