@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+  Copyright (C) 2003 by David White <davidnwhite@verizon.net>
   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
   This program is free software; you can redistribute it and/or modify
@@ -10,11 +10,13 @@
   See the COPYING file for more details.
 */
 
-#include "../display.hpp"
-
 #ifndef EDITOR_LAYOUT_H_INCLUDED
 #define EDITOR_LAYOUT_H_INCLUDED
 
+#include "global.hpp"
+
+#include "display.hpp"
+
 namespace map_editor {
 
 /// Size specifications for the map editor.
@@ -26,12 +28,14 @@ struct size_specs {
 	size_t terrain_size;
 	size_t terrain_padding;
 	size_t terrain_space;
+	size_t terrain_width;
 	size_t palette_x;
 	size_t palette_y;
 	size_t palette_h;
 	size_t palette_w;
 	size_t brush_x;
 	size_t brush_y;
+	size_t brush_padding;
 };
 
 /// Adjust the internal size specifications to fit the display.
