@@ -1,4 +1,4 @@
-/* $Id: events.cpp 11938 2006-06-08 09:53:13Z rusty $ */
+/* $Id: events.cpp 15250 2007-01-15 22:42:52Z soliton $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -204,13 +204,13 @@ void cycle_focus()
 	}
 }
 
-bool has_focus(const handler* ptr)
+bool has_focus(const handler* ptr, const SDL_Event* event)
 {
 	if(event_contexts.empty()) {
 		return true;
 	}
 
-	if(ptr->requires_event_focus() == false) {
+	if(ptr->requires_event_focus(event) == false) {
 		return true;
 	}
 
@@ -221,9 +221,19 @@ bool has_focus(const handler* ptr)
 	if(index == -1) {
 		focus_handler(ptr);
 		return true;
-	} else {
-		return event_contexts.back().handlers[index] == ptr;
+	} else if(event_contexts.back().handlers[index] == ptr){
+		return true;
+	} else if(!event_contexts.back().handlers[index]->requires_event_focus(event)) {
+		//if the currently focused handler doesn't need focus for this event
+		//allow the first-in interested handler to take care of it
+		for(int i=0; i<event_contexts.back().handlers.size(); i++) {
+			if(i != index && event_contexts.back().handlers[i]->requires_event_focus(event)) {
+				//focus_handler(event_contexts.back().handlers[i]); //steal focus?
+				return event_contexts.back().handlers[i] == ptr;
+			}
+		}
 	}
+	return false;
 }
 
 void pump()
