@@ -1,4 +1,4 @@
-/* $Id: filechooser.cpp 7533 2005-07-20 08:22:37Z ott $ */
+/* $Id: filechooser.cpp 11647 2006-05-26 01:03:08Z rusty $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -13,6 +13,8 @@
 
 #include "global.hpp"
 
+#define GETTEXT_DOMAIN "wesnoth-lib"
+
 #include "display.hpp"
 #include "gettext.hpp"
 #include "show_dialog.hpp"
@@ -87,7 +89,7 @@ int show_file_chooser_dialog(display &disp, std::string &filename,
 			}
 		}
 		disp.flip();
-		SDL_Delay(10);
+		disp.delay(10);
 	}
 }
 } //end namespace dialogs
