@@ -1,4 +1,4 @@
-/* $Id: filesystem.cpp 12753 2006-07-24 18:40:12Z sapient $ */
+/* $Id: filesystem.cpp 16920 2007-04-18 21:38:48Z noyga $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -164,6 +164,7 @@ void get_files_in_dir(const std::string& directory,
 
 		//if we have a path to find directories in, then convert relative
 		//pathnames to be rooted on the wesnoth path
+#ifndef __AMIGAOS4__
 		if(!directory.empty() && directory[0] != '/' && !game_config::path.empty()){
 			const std::string& dir = game_config::path + "/" + directory;
 			if(is_directory(dir)) {
@@ -171,6 +172,7 @@ void get_files_in_dir(const std::string& directory,
 				return;
 			}
 		}
+#endif
 
 #ifdef _WIN32
 		_finddata_t fileinfo;
@@ -226,7 +228,15 @@ void get_files_in_dir(const std::string& directory,
 #else
 		  char *filename = entry->d_name;
 #endif
+#ifndef __AMIGAOS4__
 			const std::string name((directory + "/") + filename);
+#else
+			std::string name;
+			if (directory.empty() || directory[directory.size()-1] == ':')
+				name = directory + filename;
+			else
+				name = (directory + "/") + filename;
+#endif
 
 			struct stat st;
 			if (::stat(name.c_str(), &st) != -1) {
