@@ -1,4 +1,4 @@
-/* $Id: filesystem.hpp 8269 2005-09-17 15:06:28Z ott $ */
+/* $Id: filesystem.hpp 11861 2006-06-05 11:26:38Z rusty $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -51,6 +51,7 @@ std::string get_saves_dir();
 std::string get_cache_dir();
 std::string get_intl_dir();
 std::string get_screenshot_dir();
+std::string get_upload_dir();
 std::string get_user_data_dir();
 
 std::string get_cwd();
@@ -78,6 +79,9 @@ bool file_exists(const std::string& name);
 //function to get the creation time of a file
 time_t file_create_time(const std::string& fname);
 
+//return the next ordered full filename within this directory
+std::string next_filename(const std::string &dirname, unsigned int max = 0);
+
 struct file_tree_checksum
 {
 	file_tree_checksum();
