@@ -1,4 +1,4 @@
-/* $Id: gamestatus.hpp 14736 2006-12-19 10:37:39Z edb $ */
+/* $Id: gamestatus.hpp 15083 2007-01-05 17:53:44Z jhinrichs $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -159,12 +159,12 @@ struct save_info {
 //function to get a list of available saves.
 std::vector<save_info> get_saves_list(const std::string *dir = NULL);
 
-//enum WRITE_GAME_MODE { WRITE_SNAPSHOT_ONLY, WRITE_FULL_GAME };
+enum WRITE_GAME_MODE { WRITE_SNAPSHOT_ONLY, WRITE_FULL_GAME };
 
 void read_save_file(const std::string& name, config& cfg, std::string* error_log);
 
 game_state read_game(const game_data& data, const config* cfg);
-void write_game(const game_state& game, config& cfg/*, WRITE_GAME_MODE mode=WRITE_FULL_GAME*/);
+void write_game(const game_state& game, config& cfg, WRITE_GAME_MODE mode=WRITE_FULL_GAME);
 
 // function returns true iff there is already savegame with that name
 bool save_game_exists(const std::string & name);
