@@ -1,4 +1,4 @@
-/* $Id: gettext.cpp 7533 2005-07-20 08:22:37Z ott $ */
+/* $Id: gettext.cpp 15612 2007-02-06 15:50:12Z torangan $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -48,3 +48,30 @@ const char* dsgettext (const char * domainname, const char *msgid)
 	}
 	return msgval;
 }
+
+const char* sngettext (const char *singular, const char *plural, int n)
+{
+	const char *msgval = ngettext (singular, plural, n);
+	if (msgval == singular) {
+		msgval = strrchr (singular, '^');
+		if (msgval == NULL)
+			msgval = singular;
+		else
+			msgval++;
+	}
+	return msgval;
+}
+
+const char* dsngettext (const char * domainname, const char *singular, const char *plural, int n)
+{
+	bind_textdomain_codeset(domainname, "UTF-8");
+	const char *msgval = dngettext (domainname, singular, plural, n);
+	if (msgval == singular) {
+		msgval = strrchr (singular, '^');
+		if (msgval == NULL)
+			msgval = singular;
+		else
+			msgval++;
+	}
+	return msgval;
+}
