@@ -1,4 +1,4 @@
-/* $Id: hotkeys.hpp 8267 2005-09-17 14:01:49Z morloth $ */
+/* $Id: hotkeys.hpp 11930 2006-06-08 01:14:52Z sapient $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -35,13 +35,15 @@ enum HOTKEY_COMMAND {
 	HOTKEY_FULLSCREEN, HOTKEY_SCREENSHOT, HOTKEY_ACCELERATED,
 	HOTKEY_UNIT_DESCRIPTION, HOTKEY_RENAME_UNIT, HOTKEY_SAVE_GAME, HOTKEY_LOAD_GAME,
 	HOTKEY_RECRUIT, HOTKEY_REPEAT_RECRUIT, HOTKEY_RECALL, HOTKEY_ENDTURN,
-	HOTKEY_TOGGLE_GRID, HOTKEY_STATUS_TABLE, HOTKEY_MUTE,
+	HOTKEY_TOGGLE_GRID, HOTKEY_STATUS_TABLE, HOTKEY_MUTE, HOTKEY_MOUSE_SCROLL,
 	HOTKEY_SPEAK, HOTKEY_CREATE_UNIT, HOTKEY_CHANGE_UNIT_SIDE, HOTKEY_PREFERENCES,
 	HOTKEY_OBJECTIVES, HOTKEY_UNIT_LIST, HOTKEY_STATISTICS, HOTKEY_QUIT_GAME,
-	HOTKEY_LABEL_TERRAIN, HOTKEY_SHOW_ENEMY_MOVES, HOTKEY_BEST_ENEMY_MOVES,
+	HOTKEY_LABEL_TERRAIN, HOTKEY_CLEAR_LABELS,HOTKEY_SHOW_ENEMY_MOVES, HOTKEY_BEST_ENEMY_MOVES,
 	HOTKEY_DELAY_SHROUD, HOTKEY_UPDATE_SHROUD, HOTKEY_CONTINUE_MOVE,
 	HOTKEY_SEARCH, HOTKEY_SPEAK_ALLY, HOTKEY_SPEAK_ALL, HOTKEY_HELP,
 	HOTKEY_CHAT_LOG, HOTKEY_LANGUAGE,
+	HOTKEY_PLAY_REPLAY, HOTKEY_RESET_REPLAY, HOTKEY_STOP_REPLAY, HOTKEY_REPLAY_NEXT_TURN,
+	HOTKEY_REPLAY_NEXT_SIDE, HOTKEY_REPLAY_SHROUD, HOTKEY_REPLAY_FOG, HOTKEY_REPLAY_SKIP_ANIMATION,
 
 	//editing specific commands
 	HOTKEY_EDIT_SET_TERRAIN,
@@ -69,13 +71,25 @@ public:
 	void load_from_config(const config& cfg);
 
 	void set_description(const std::string& description);
-	void set_key(int keycode, bool alt, bool ctrl, bool shift, bool cmd);
+	void set_key(int character, int keycode, bool shift, bool ctrl, bool alt, bool cmd);
 
-	int get_keycode() const { return keycode_; };
-	bool get_alt() const { return alt_; };
-	bool get_ctrl() const { return ctrl_; };
-	bool get_shift() const { return shift_; };
-	bool get_cmd() const { return cmd_; };
+	enum type {
+		UNBOUND,
+		BY_KEYCODE,
+		BY_CHARACTER,
+	};
+
+	enum type get_type() const { return type_; }
+
+	// Returns unicode value of keypress.
+	int get_character() const { return character_; }
+	bool get_alt() const { return alt_; }
+	bool get_cmd() const { return cmd_; }
+	bool get_ctrl() const { return ctrl_; }
+
+	// Return the actual key code.
+	int get_keycode() const { return keycode_; }
+	bool get_shift() const { return shift_; }
 
 	// Return "name" of hotkey for example :"ctrl+alt+g"
 	std::string get_name() const;
@@ -87,11 +101,20 @@ private:
 	std::string command_;
 	std::string description_;
 
-	int keycode_;
-	bool shift_;
+	// UNBOUND means unset, CHARACTER means see character_, KEY means keycode_.
+	enum type type_;
+
+	// Actual unicode character
+	int character_;
 	bool ctrl_;
 	bool alt_;
 	bool cmd_;
+
+	// These used for function keys (which don't have a unicode value) or
+	// space (which doesn't have a distinct unicode value when shifted).
+	int keycode_;
+	bool shift_;
+
 	bool hidden_;
 };
 
@@ -108,12 +131,9 @@ void save_hotkeys(config& cfg);
 
 hotkey_item& get_hotkey(HOTKEY_COMMAND id);
 hotkey_item& get_hotkey(const std::string& command);
-//the "mods" parameter distinguishes between two modes of operation. If mods
-//are disallowed (mods == false), then any match must be exact. I.e. "shift+a"
-//does not match "a". If they are allowed (mods == true), then shift+a will
-//match "a"
-hotkey_item& get_hotkey(int keycode, bool shift, bool ctrl, bool alt, bool cmd, bool mods = false);
-hotkey_item& get_hotkey(const SDL_KeyboardEvent& event, bool mods = false);
+
+hotkey_item& get_hotkey(int character, int keycode, bool shift, bool ctrl, bool alt, bool cmd);
+hotkey_item& get_hotkey(const SDL_KeyboardEvent& event);
 
 hotkey_item& get_visible_hotkey(int index);
 
@@ -154,6 +174,7 @@ public:
 	virtual void unit_list() {}
 	virtual void show_statistics() {}
 	virtual void label_terrain() {}
+	virtual void clear_labels() {}
 	virtual void show_enemy_moves(bool /*ignore_units*/) {}
 	virtual void toggle_shroud_updates() {}
 	virtual void update_shroud_now() {}
@@ -163,6 +184,14 @@ public:
 	virtual void show_chat_log() {}
 	virtual void user_command() {}
 	virtual void change_language() {}
+	virtual void play_replay() {}
+	virtual void reset_replay() {}
+	virtual void stop_replay() {}
+	virtual void replay_next_turn() {}
+	virtual void replay_next_side() {}
+	virtual void replay_switch_shroud() {}
+	virtual void replay_switch_fog() {}
+	virtual void replay_skip_animation() {}
 
 	// Map editor stuff.
 	virtual void edit_set_terrain() {}
@@ -185,11 +214,15 @@ public:
 	virtual void edit_refresh() {}
 
 	//Gets the action's image (if any). Displayed left of the action text in menus.
-	virtual std::string get_action_image(hotkey::HOTKEY_COMMAND command) const { return ""; }
+	virtual std::string get_action_image(hotkey::HOTKEY_COMMAND /*command*/) const { return ""; }
 	//Does the action control a toggle switch? If so, return the state of the action (on or off)
-	virtual ACTION_STATE get_action_state(hotkey::HOTKEY_COMMAND command) const { return ACTION_STATELESS; }
+	virtual ACTION_STATE get_action_state(hotkey::HOTKEY_COMMAND /*command*/) const { return ACTION_STATELESS; }
 	//Returns the appropriate menu image. Checkable items will get a checked/unchecked image.
 	std::string get_menu_image(hotkey::HOTKEY_COMMAND command) const;
+	//Returns a vector of images for a given menu
+	std::vector<std::string> get_menu_images(const std::vector<std::string>& items_arg);
+
+	void show_menu(const std::vector<std::string>& items_arg, int xloc, int yloc, bool context_menu, display& gui,const std::vector<std::string>& savenames = std::vector<std::string>());
 
 	virtual bool can_execute_command(HOTKEY_COMMAND command) const = 0;
 };
