@@ -1,4 +1,4 @@
-/* $Id: image.cpp 12681 2006-07-21 05:40:01Z sapient $ */
+/* $Id: image.cpp 16259 2007-03-16 18:42:16Z mordante $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -54,11 +54,7 @@ int red_adjust = 0, green_adjust = 0, blue_adjust = 0;
 
 std::string image_mask;
 
-#ifdef USE_TINY_GUI
-const int tile_size = 36;
-#else
 const int tile_size = 72;
-#endif
 int zoom = tile_size;
 
 //The "pointer to surfaces" vector is not cleared anymore (the surface are
