@@ -1,6 +1,6 @@
-/* $Id: log.cpp,v 1.24 2005/05/01 09:54:30 silene Exp $ */
+/* $Id: log.cpp 7645 2005-07-31 18:56:58Z j_daniel $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
                  2004 by Guillaume Melquiond <guillaume.melquiond@gmail.com>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
@@ -51,7 +51,7 @@ void timestamps(bool t) { timestamp = t; }
 
 logger err("error", 0), warn("warning", 1), info("info", 2);
 log_domain general("general"), ai("ai"), config("config"), display("display"), engine("engine"),
-           network("network"), filesystem("filesystem");
+           network("network"), filesystem("filesystem"), audio("audio");
 
 log_domain::log_domain(char const *name) : domain_(log_domains.size())
 {
