@@ -1,4 +1,4 @@
-/* $Id: map_label.hpp 7533 2005-07-20 08:22:37Z ott $ */
+/* $Id: map_label.hpp 9980 2006-02-05 00:34:03Z boucman $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -16,6 +16,7 @@
 
 class config;
 #include "map.hpp"
+#include "font.hpp"
 
 #include <map>
 #include <string>
@@ -36,7 +37,7 @@ public:
 	static int get_max_chars();
 
 	const std::string& get_label(const gamemap::location& loc) const;
-	void set_label(const gamemap::location& loc, const std::string& text);
+	void set_label(const gamemap::location& loc, const std::string& text, const SDL_Color colour = font::NORMAL_COLOUR);
 	void clear();
 
 	void scroll(double xmove, double ymove);
