@@ -233,7 +233,7 @@ namespace events{
 									_("Name") + COLUMN_SEPARATOR +
 									_("HP") + COLUMN_SEPARATOR +
 									_("XP") + COLUMN_SEPARATOR +
-									_("Traits") + COLUMN_SEPARATOR +
+									_("unit list^Traits") + COLUMN_SEPARATOR +
 									_("Moves") + COLUMN_SEPARATOR +
 									_("Location");
 
@@ -294,16 +294,19 @@ namespace events{
 	void menu_handler::status_table()
 	{
 		std::stringstream heading;
-		heading << HEADING_PREFIX << _("Leader") << COLUMN_SEPARATOR << ' ' << COLUMN_SEPARATOR
+		heading << HEADING_PREFIX << ' ' << COLUMN_SEPARATOR
+				<< _("Leader") << COLUMN_SEPARATOR << ' ' << COLUMN_SEPARATOR
+				<< _("Team") << COLUMN_SEPARATOR
 				<< _("Gold") << COLUMN_SEPARATOR
 				<< _("Villages") << COLUMN_SEPARATOR
-				<< _("Units") << COLUMN_SEPARATOR
+				<< _("status^Units") << COLUMN_SEPARATOR
 				<< _("Upkeep") << COLUMN_SEPARATOR
 				<< _("Income");
 
 		gui::menu::basic_sorter sorter;
-		sorter.set_redirect_sort(0,1).set_alpha_sort(1).set_numeric_sort(2).set_numeric_sort(3)
-			  .set_numeric_sort(4).set_numeric_sort(5).set_numeric_sort(6).set_numeric_sort(7);
+		sorter.set_id_sort(0).set_redirect_sort(1,2).set_alpha_sort(2).set_alpha_sort(3)
+			.set_numeric_sort(4).set_numeric_sort(5).set_numeric_sort(6)
+			.set_numeric_sort(7).set_numeric_sort(8).set_numeric_sort(9);
 
 		if(game_config::debug)
 			heading << COLUMN_SEPARATOR << _("Gold");
@@ -336,13 +339,15 @@ namespace events{
 			const unit_map::const_iterator leader = team_leader(n+1,units_);
 			//output the number of the side first, and this will
 			//cause it to be displayed in the correct colour
+			char side = lexical_cast<char, size_t>(n+1);
+			str << "\033[3" << side << 'm' << side << ". " << COLUMN_SEPARATOR;
 			if(leader != units_.end()) {
 				str << IMAGE_PREFIX << leader->second.absolute_image() << "~TC(" << (n+1) << "," << leader->second.team_color() << ")" << COLUMN_SEPARATOR
-					<< "\033[3" << lexical_cast<char, size_t>(n+1) << 'm' << teams_[n].current_player() /*leader->second.description()*/ << COLUMN_SEPARATOR;
+					<< "\033[3" << side << 'm' << teams_[n].current_player() /*leader->second.description()*/ << COLUMN_SEPARATOR;
 			} else {
-				str << ' ' << COLUMN_SEPARATOR << "\033[3" << lexical_cast<char, size_t>(n+1) << "m-" << COLUMN_SEPARATOR;
+				str << ' ' << COLUMN_SEPARATOR << "\033[3" << side << "m-" << COLUMN_SEPARATOR;
 			}
-
+			str << teams_[n].user_team_name() << COLUMN_SEPARATOR;
 			if(enemy && viewing_team.uses_fog()) {
 				str << ' ' << COLUMN_SEPARATOR;
 			} else {
@@ -359,8 +364,9 @@ namespace events{
 		}
 
 		if(fog)
-			items.push_back(IMAGE_PREFIX + std::string("random-enemy.png") + COLUMN_SEPARATOR +
-							IMAGE_PREFIX + "random-enemy.png");
+			items.push_back(std::string(" ") + COLUMN_SEPARATOR +
+			               IMAGE_PREFIX + "random-enemy.png" + COLUMN_SEPARATOR +
+			               IMAGE_PREFIX + "random-enemy.png");
 
 		gui::show_dialog2(*gui_,NULL,"","",gui::CLOSE_ONLY,&items,
 						 NULL,"",NULL,0,NULL,NULL,-1,-1,NULL,NULL,"",&sorter);
@@ -425,6 +431,7 @@ namespace events{
 			buf << side_num;
 			side["side"] = buf.str();
 
+			//current visible units
 			for(unit_map::const_iterator i = units_.begin(); i != units_.end(); ++i) {
 				if(i->second.side() == side_num) {
 					config& u = side.add_child("unit");
@@ -432,6 +439,19 @@ namespace events{
 					i->second.write(u);
 				}
 			}
+			//recall list
+			{
+				for(std::map<std::string, player_info>::const_iterator i=gamestate_.players.begin();
+				i!=gamestate_.players.end(); ++i) {
+					for(std::vector<unit>::const_iterator j = i->second.available_units.begin();
+						j != i->second.available_units.end(); ++j) {
+						if (j->side() == side_num){
+							config& u = side.add_child("unit");
+							j->write(u);
+						}
+					}
+				}
+			}
 		}
 
 		status_.write(start);
@@ -565,7 +585,7 @@ namespace events{
 
 			description << font::IMAGE << type.image() << "~TC(" << team_num << "," << type.flag_rgb() << ")" << COLUMN_SEPARATOR << font::LARGE_TEXT
 						<< prefix << type.language_name() << "\n"
-						<< prefix << type.cost() << " " << sgettext("unit^Gold");
+						<< prefix << type.cost() << " " << sngettext("unit^Gold", "Gold", type.cost());
 			items.push_back(description.str());
 			sample_units.push_back(unit(&gameinfo_,&units_,&map_,&status_,&teams_,&type,team_num));
 		}
@@ -737,7 +757,10 @@ namespace events{
 					std::stringstream msg;
 					utils::string_map i18n_symbols;
 					i18n_symbols["cost"] = lexical_cast<std::string>(game_config::recall_cost);
-					msg << vgettext("You must have at least $cost gold pieces to recall a unit", i18n_symbols);
+					msg << vngettext("You must have at least 1 gold piece to recall a unit",
+						"You must have at least $cost gold pieces to recall a unit",
+						game_config::recall_cost,
+						i18n_symbols);
 					gui::show_dialog(*gui_,NULL,"",msg.str());
 				} else {
 					std::cerr << "recall index: " << res << "\n";
@@ -1224,26 +1247,13 @@ namespace events{
 	{
 		wassert(ui != units_.end());
 
-		unit u = ui->second;
-		const shortest_path_calculator calc(u,teams_[team_num - 1],mousehandler.visible_units(),teams_,map_);
+		paths::route route = mousehandler.get_route(ui, target, teams_[team_num - 1]);
 
-		const std::set<gamemap::location>* teleports = NULL;
-
-		std::set<gamemap::location> allowed_teleports;
-		if(u.get_ability_bool("teleport",ui->first)) {
-			allowed_teleports = vacant_villages(teams_[team_num - 1].villages(),units_);
-			teleports = &allowed_teleports;
-			if(teams_[team_num - 1].villages().count(ui->first))
-				allowed_teleports.insert(ui->first);
-		}
-
-		paths::route route = a_star_search(ui->first, target, 10000.0, &calc, map_.x(), map_.y(), teleports);
 		if(route.steps.empty())
 			return;
 
 		wassert(route.steps.front() == ui->first);
 
-		route.move_left = route_turns_to_complete(ui->second,map_,route);
 		gui_->set_route(&route);
 		move_unit(gui_,gameinfo_,status_,map_,units_,teams_,route.steps,&recorder,&undo_stack_,NULL,continue_move);
 		gui_->invalidate_game_status();
