@@ -1,4 +1,4 @@
-/* $Id: multiplayer_connect.hpp 14883 2006-12-27 13:35:38Z boucman $ */
+/* $Id: multiplayer_connect.hpp 15522 2007-02-01 22:00:47Z jhinrichs $ */
 /*
    Copyright (C)
    Part of the Battle for Wesnoth Project http://www.wesnoth.org
@@ -174,6 +174,9 @@ private:
 	void load_game();
 	void lists_init();
 
+	//convenience function
+	config* current_config();
+
 	// Updates the level_ variable to reflect the sides in the sides_ vector
 	void update_level();
 
