@@ -1,4 +1,4 @@
-/* $Id: multiplayer_lobby.cpp 14129 2006-11-01 11:25:22Z edb $ */
+/* $Id: multiplayer_lobby.cpp 19129 2007-07-26 10:37:50Z soliton $ */
 /*
    Copyright (C)
    Part of the Battle for Wesnoth Project http://www.wesnoth.org
@@ -49,6 +49,7 @@ namespace mp {
 	v_padding_(5), header_height_(20), selected_(0), visible_range_(std::pair<size_t,size_t>(0,0)),
 	double_clicked_(false), ignore_next_doubleclick_(false), last_was_doubleclick_(false)
 {
+	set_numeric_keypress_selection(false);
 }
 
 void gamebrowser::set_inner_location(const SDL_Rect& rect)
@@ -151,7 +152,7 @@ void gamebrowser::draw_row(const size_t index, const SDL_Rect& item_rect, ROW_TY
 	xpos += gold_icon->w + h_padding_;
 
 	// draw gold text
-	const surface gold_text(font::get_rendered_text(game.gold, font::SIZE_NORMAL, font::NORMAL_COLOUR));
+	const surface gold_text(font::get_rendered_text(game.gold, font::SIZE_NORMAL, game.use_map_settings ? font::DISABLED_COLOUR : font::NORMAL_COLOUR));
 	ypos -= abs(gold_icon->h - gold_text->h) / 2;
 	video().blit_surface(xpos, ypos, gold_text);
 
@@ -194,10 +195,17 @@ void gamebrowser::draw_row(const size_t index, const SDL_Rect& item_rect, ROW_TY
 	xpos += vision_icon->w + h_padding_;
 
 	const surface status_text(font::get_rendered_text(game.status, font::SIZE_NORMAL, font_color));
-	const surface vision_text(font::get_rendered_text(font::make_text_ellipsis(game.vision, font::SIZE_NORMAL, maximum<int>((item_rect.x + item_rect.w - margin_ - status_text->w - 2 * h_padding_) - xpos, 0)),font::SIZE_NORMAL, font::NORMAL_COLOUR));
+	const surface vision_text(font::get_rendered_text(font::make_text_ellipsis(game.vision, font::SIZE_NORMAL, maximum<int>((item_rect.x + item_rect.w - margin_ - status_text->w - 2 * h_padding_) - xpos, 0)),font::SIZE_NORMAL, game.use_map_settings ? font::DISABLED_COLOUR : font::NORMAL_COLOUR));
 	// draw vision text
 	video().blit_surface(xpos, ypos, vision_text);
 
+	// draw map settings text
+	if (game.use_map_settings) {
+		const surface map_settings_text(font::get_rendered_text(_("Use map settings"), font::SIZE_NORMAL, font::NORMAL_COLOUR));
+		xpos += vision_text->w + 4 * h_padding_;
+		video().blit_surface(xpos, ypos, map_settings_text);
+	}
+
 	// draw status text
 	xpos = item_rect.x + item_rect.w - margin_ - status_text->w;
 	video().blit_surface(xpos, ypos, status_text);
@@ -210,7 +218,7 @@ void gamebrowser::handle_event(const SDL_Event& event)
 {
 	scrollarea::handle_event(event);
 	if(event.type == SDL_KEYDOWN) {
-		if(focus() && !games_.empty()) {
+		if(focus(&event) && !games_.empty()) {
 			switch(event.key.keysym.sym) {
 				case SDLK_UP:
 					if(selected_ > 0) {
@@ -300,8 +308,27 @@ void gamebrowser::handle_event(const SDL_Event& event)
 		}
 	}
 }
+
+struct minimap_cache_item {
+	std::string map_data;
+	surface mini_map;
+	std::string map_info_size;
+};
+
 void gamebrowser::set_game_items(const config& cfg, const config& game_config)
 {
+	const bool scrolled_to_max = (has_scrollbar() && get_position() == get_max_position());
+
+	// don't throw the rendered minimaps away
+	std::vector<minimap_cache_item> minimap_cache;
+	for(std::vector<game_item>::iterator oldgame = games_.begin(); oldgame != games_.end(); ++oldgame) {
+		minimap_cache_item item;
+		item.map_data = oldgame->map_data;
+		item.mini_map = oldgame->mini_map;
+		item.map_info_size = oldgame->map_info_size;
+		minimap_cache.push_back(item);
+	}
+		
 	games_.clear();
 	config::child_list games = cfg.get_children("game");
 	config::child_iterator game;
@@ -321,9 +348,25 @@ void gamebrowser::set_game_items(const config& cfg, const config& game_config)
 
 		if(games_.back().map_data != "") {
 			try {
-				gamemap map(game_config, games_.back().map_data);
-				games_.back().mini_map = image::getMinimap(item_height_ - margin_, item_height_ - 2 * margin_, map, 0);
-				games_.back().map_info += " - " + lexical_cast_default<std::string, int>(map.x(), "??") + std::string("x") + lexical_cast_default<std::string, int>(map.y(), "??");
+				std::vector<minimap_cache_item>::iterator i;
+				bool found = false;
+				for(i = minimap_cache.begin(); i != minimap_cache.end() && !found; ++i) {
+					if (i->map_data == games_.back().map_data) {
+						found = true;
+						games_.back().map_info_size = i->map_info_size;
+						games_.back().mini_map = i->mini_map;
+					}
+				}
+				if (!found) {
+					// parsing the map and generating the minimap are both cpu expensive
+					gamemap map(game_config, games_.back().map_data);
+					games_.back().mini_map = image::getMinimap(item_height_ - margin_, item_height_ - 2 * margin_, map, 0);
+					games_.back().map_info_size = lexical_cast_default<std::string, int>
+						(map.x(), "??") + std::string("x") + lexical_cast_default<std::string, int>(map.y(), "??");
+				}
+
+				games_.back().map_info += " - " + games_.back().map_info_size;
+				
 			} catch(gamemap::incorrect_format_exception &e) {
 				std::cerr << "illegal map: " << e.msg_ << "\n";
 			}
@@ -367,31 +410,29 @@ void gamebrowser::set_game_items(const config& cfg, const config& game_config)
 		}
 
 		if((**game)["mp_use_map_settings"] == "yes") {
-			games_.back().gold = _("Use map settings");
-			games_.back().vision = _("Use map settings");
 			games_.back().use_map_settings = true;
 		} else {
 			games_.back().use_map_settings = false;
-			games_.back().gold = (**game)["mp_village_gold"];
-			if((**game)["mp_fog"] == "yes") {
-				games_.back().vision = _("Fog");
-				games_.back().fog = true;
-				if((**game)["mp_shroud"] == "yes") {
-					games_.back().vision += "/";
-					games_.back().vision += _("Shroud");
-					games_.back().shroud = true;
-				} else {
-					games_.back().shroud = false;
-				}
-			} else if((**game)["mp_shroud"] == "yes") {
-				games_.back().vision = _("Shroud");
-				games_.back().fog = false;
+		}
+		games_.back().gold = (**game)["mp_village_gold"];
+		if((**game)["mp_fog"] == "yes") {
+			games_.back().vision = _("Fog");
+			games_.back().fog = true;
+			if((**game)["mp_shroud"] == "yes") {
+				games_.back().vision += "/";
+				games_.back().vision += _("Shroud");
 				games_.back().shroud = true;
 			} else {
-				games_.back().vision = _("none");
-				games_.back().fog = false;
 				games_.back().shroud = false;
 			}
+		} else if((**game)["mp_shroud"] == "yes") {
+			games_.back().vision = _("Shroud");
+			games_.back().fog = false;
+			games_.back().shroud = true;
+		} else {
+			games_.back().vision = _("none");
+			games_.back().fog = false;
+			games_.back().shroud = false;
 		}
 		if((**game)["mp_countdown"] == "yes" ) {
 			games_.back().time_limit = (**game)["mp_countdown_init_time"] + " / +" + (**game)["mp_countdown_turn_bonus"] + " " + (**game)["mp_countdown_action_bonus"];
@@ -404,6 +445,9 @@ void gamebrowser::set_game_items(const config& cfg, const config& game_config)
 	}
 	set_full_size(games_.size());
 	set_shown_size(inner_location().h / row_height());
+	if(scrolled_to_max) {
+		set_position(get_max_position());
+	}
 	scroll(get_position());
 	if(selected_ >= games_.size())
 		selected_ = maximum<long>(static_cast<long>(games_.size()) - 1, 0);
