@@ -1,4 +1,4 @@
-/* $Id: multiplayer_ui.cpp 15522 2007-02-01 22:00:47Z jhinrichs $ */
+/* $Id: multiplayer_ui.cpp 18326 2007-06-16 21:45:56Z noyga $ */
 /*
    Copyright (C) 2005
    Part of the Battle for Wesnoth Project http://www.wesnoth.org
@@ -69,18 +69,34 @@ void level_to_gamestate(config& level, game_state& state, bool saved_game)
 	state.campaign_type = "multiplayer";
 	state.version = level["version"];
 
+	// [variables] might be used in a normal scenario too
+	const config* const vars = level.child("variables");
+	if(vars != NULL) {
+		state.variables = *vars;
+	}
 	//If we start a fresh game, there won't be any snapshot information. If however this
 	//is a savegame, we got a valid snapshot here.
 	if (saved_game){
 		state.snapshot = *(level.child("snapshot"));
 
-		const config* const vars = level.child("variables");
-		if(vars != NULL) {
-			state.variables = *vars;
+		if (state.snapshot.child("variables") != NULL){
+			state.variables = *state.snapshot.child("variables");
 		}
-		else{
-			if (state.snapshot.child("variables") != NULL){
-				state.variables = *state.snapshot.child("variables");
+
+		//We also need to take into account, that the reload could take place with different players.
+		//If so, they are substituted now.
+		const config::child_list& snapshot_sides = state.snapshot.get_children("side");
+		const config::child_list& level_sides = level.get_children("side");
+		for(config::child_list::const_iterator side = snapshot_sides.begin(); side != snapshot_sides.end(); ++side) {
+			for(config::child_list::const_iterator lside = level_sides.begin(); lside != level_sides.end(); ++lside) {
+				if ( ((**side)["side"] == (**lside)["side"]) 
+					&& ((**side)["current_player"] != (**lside)["current_player"]) ){
+					(**side)["current_player"] = (**lside)["current_player"];
+					(**side)["description"] = (**lside)["description"];
+					(**side)["save_id"] = (**lside)["save_id"];
+					(**side)["controller"] = (**lside)["controller"];
+					break;
+				}
 			}
 		}
 	}
