@@ -1,4 +1,4 @@
-/* $Id: multiplayer_ui.hpp 13991 2006-10-16 12:22:13Z rusty $ */
+/* $Id: multiplayer_ui.hpp 15228 2007-01-14 00:56:57Z jhinrichs $ */
 /*
    Copyright (C)
    Part of the Battle for Wesnoth Project http://www.wesnoth.org
@@ -39,7 +39,7 @@ enum controller { CNTR_NETWORK = 0, CNTR_LOCAL, CNTR_COMPUTER, CNTR_EMPTY, CNTR_
 
 void check_response(network::connection res, const config& data);
 
-void level_to_gamestate(config& level, game_state& state);
+void level_to_gamestate(config& level, game_state& state, bool saved_game = false);
 
 std::string get_colour_string(int id);
 
