@@ -1,4 +1,4 @@
-/* $Id: multiplayer_wait.cpp 14883 2006-12-27 13:35:38Z boucman $ */
+/* $Id: multiplayer_wait.cpp 16074 2007-02-25 17:26:31Z noyga $ */
 /*
    Copyright (C)
    Part of the Battle for Wesnoth Project http://www.wesnoth.org
@@ -14,6 +14,7 @@
 #include "global.hpp"
 
 #include "display.hpp"
+#include "game_events.hpp"
 #include "gettext.hpp"
 #include "log.hpp"
 #include "marked-up_text.hpp"
@@ -159,6 +160,7 @@ wait::wait(display& disp, const config& cfg, const game_data& data, mp::chat& c,
 	game_data_(data),
 	stop_updates_(false)
 {
+	game_menu_.set_numeric_keypress_selection(false);
 	gamelist_updated();
 }
 
@@ -176,7 +178,9 @@ void wait::join_game(bool observe)
 		check_response(data_res, level_);
 
 		//if we have got valid side data
-		if(level_.child("gamelist") == NULL)
+		//the first condition is to make sure that we don't have another
+		//WML message with a side-tag in it
+		if( (level_.values.find("version") != level_.values.end()) && (level_.child("side") != NULL) )
 			break;
 	}
 
@@ -274,13 +278,17 @@ const game_state& wait::get_state()
 
 void wait::start_game()
 {
+	// add era events
+	const config* const era_cfg = level_.child("era");
+	game_events::add_events(era_cfg->get_children("event"),"all");
+
 	config const * const stats = level_.child("statistics");
 	if(stats != NULL) {
 		statistics::fresh_stats();
 		statistics::read_stats(*stats);
 	}
 
-	level_to_gamestate(level_, state_);
+	level_to_gamestate(level_, state_, level_["savegame"] == "yes");
 
 	LOG_NW << "starting game\n";
 }
@@ -415,7 +423,7 @@ void wait::generate_menu()
 		str << COLUMN_SEPARATOR;
 		// Don't show gold for saved games
 		if(sd["allow_changes"] == "yes")
-			str << sd["gold"] << ' ' << sgettext("unit^Gold") << COLUMN_SEPARATOR;
+			str << sd["gold"] << ' ' << _("Gold") << COLUMN_SEPARATOR;
 
 		int income_amt = lexical_cast_default<int>(sd["income"], 0);
 		if(income_amt != 0){
