@@ -1,4 +1,4 @@
-/* $Id: multiplayer_wait.hpp 7120 2005-06-04 19:16:06Z ott $ */
+/* $Id: multiplayer_wait.hpp 11657 2006-05-27 05:21:16Z sapient $ */
 /*
    Copyright (C)
    Part of the Battle for Wesnoth Project http://www.wesnoth.org
@@ -38,6 +38,9 @@ public:
 
 	void start_game();
 
+	// Gets current game snapshot if observer wants to skip the replay
+	game_state& request_snapshot();
+
 protected:
 	virtual void layout_children(const SDL_Rect& rect);
 	virtual void hide_children(bool hide=true);
@@ -54,6 +57,7 @@ private:
 		void set_selection(int index);
 		std::string get_selected_leader();
 
+		void join();
 	private:
 		virtual void draw_contents();
 		virtual void process_event();
