@@ -1,4 +1,4 @@
-/* $Id: network.cpp 7938 2005-08-20 19:12:01Z j_daniel $ */
+/* $Id: network.cpp 12503 2006-07-11 20:57:03Z noyga $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -34,6 +34,9 @@
 
 #include <signal.h>
 #if defined(_WIN32) || defined(__WIN32__) || defined (WIN32)
+#undef INADDR_ANY
+#undef INADDR_BROADCAST
+#undef INADDR_NONE
 #include <windows.h>
 #else
 #include <sys/types.h>
@@ -189,7 +192,7 @@ manager::manager(size_t nthreads) : free_(true)
 	}
 
 	//on Unix-based systems, set sigpipe to be ignored
-#if !(defined(_WIN32) || defined(__APPLE__))
+#if !(defined(_WIN32) || defined(__APPLE__) || defined(__AMIGAOS4__))
 	WRN_NW << "ignoring SIGPIPE\n";
 	signal(SIGPIPE,SIG_IGN);
 #endif
@@ -500,20 +503,25 @@ connection accept_connection()
 	return 0;
 }
 
-void disconnect(connection s)
+bool disconnect(connection s)
 {
 	if(s == 0) {
 		while(sockets.empty() == false) {
 			wassert(sockets.back() != 0);
-			disconnect(sockets.back());
+			while(disconnect(sockets.back()) == false) {
+				SDL_Delay(10);
+			}
 		}
 
-		return;
+		return true;
 	}
 
 	const connection_map::iterator info = connections.find(s);
 	if(info != connections.end()) {
-		network_worker_pool::close_socket(info->second.sock);
+		const bool res = network_worker_pool::close_socket(info->second.sock);
+		if(res == false) {
+			return false;
+		}
 	}
 
 	schemas.erase(s);
@@ -540,6 +548,8 @@ void disconnect(connection s)
 			LOG_NW << "valid socket: " << (int)*sockets.begin() << "\n";
 		}
 	}
+
+	return true;
 }
 
 void queue_disconnect(network::connection sock)
@@ -653,16 +663,7 @@ connection receive_data(config& cfg, connection connection_num)
 	return result;
 }
 
-namespace {
-	size_t default_max_send_size = 0;
-}
-
-void set_default_send_size(size_t max_size)
-{
-	default_max_send_size = max_size;
-}
-
-void send_data(const config& cfg, connection connection_num, size_t max_size, SEND_TYPE mode)
+void send_data(const config& cfg, connection connection_num)
 {
 	LOG_NW << "in send_data()...\n";
 	if(cfg.empty()) {
@@ -673,14 +674,6 @@ void send_data(const config& cfg, connection connection_num, size_t max_size, SE
 		return;
 	}
 
-	if(max_size == 0) {
-		max_size = default_max_send_size;
-	}
-
-	if(max_size > 0 && max_size < 8) {
-		max_size = 8;
-	}
-
 	log_scope2(network, "sending data");
 	if(!connection_num) {
 		LOG_NW << "sockets: " << sockets.size() << "\n";
@@ -716,22 +709,22 @@ void send_data(const config& cfg, connection connection_num, size_t max_size, SE
 
 void queue_data(const config& cfg, connection connection_num)
 {
-	send_data(cfg,connection_num,0,QUEUE_ONLY);
+	send_data(cfg,connection_num);
 }
 
-void process_send_queue(connection connection_num, size_t max_size)
+void process_send_queue(connection, size_t)
 {
 	check_error();
 }
 
-void send_data_all_except(const config& cfg, connection connection_num, size_t max_size)
+void send_data_all_except(const config& cfg, connection connection_num)
 {
 	for(sockets_list::const_iterator i = sockets.begin(); i != sockets.end(); ++i) {
 		if(*i == connection_num) {
 			continue;
 		}
 
-		send_data(cfg,*i,max_size);
+		send_data(cfg,*i);
 	}
 }
 
