@@ -1,4 +1,4 @@
-/* $Id: network_worker.cpp 8583 2005-10-16 00:16:59Z dave $ */
+/* $Id: network_worker.cpp 12503 2006-07-11 20:57:03Z noyga $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -28,7 +28,15 @@
 #include <map>
 #include <vector>
 
+#ifdef __AMIGAOS4__
+#include <unistd.h>
+//#include <sys/clib2_net.h>
+#endif
+
 #if defined(_WIN32) || defined(__WIN32__) || defined (WIN32)
+#  undef INADDR_ANY
+#  undef INADDR_BROADCAST
+#  undef INADDR_NONE
 #  include <windows.h>
 #  define USE_SELECT 1
 #else
@@ -135,7 +143,7 @@ SOCKET_STATE send_buf(TCPsocket sock, std::vector<char>& buf) {
 			{
 
 #ifdef USE_POLL
-				struct pollfd fd = { ((_TCPsocket*)sock)->channel, POLLOUT };
+				struct pollfd fd = { ((_TCPsocket*)sock)->channel, POLLOUT, 0 };
 				int poll_res;
 				do {
 					poll_res = poll(&fd, 1, 15000);
@@ -224,7 +232,7 @@ SOCKET_STATE receive_buf(TCPsocket sock, std::vector<char>& buf)
 			{
 
 #ifdef USE_POLL
-				struct pollfd fd = { ((_TCPsocket*)sock)->channel, POLLIN };
+				struct pollfd fd = { ((_TCPsocket*)sock)->channel, POLLIN, 0 };
 				int poll_res;
 				do {
 					poll_res = poll(&fd, 1, 15000);
@@ -262,7 +270,7 @@ SOCKET_STATE receive_buf(TCPsocket sock, std::vector<char>& buf)
 	return SOCKET_READY;
 }
 
-int process_queue(void* data)
+int process_queue(void*)
 {
 	LOG_NW << "thread started...\n";
 	for(;;) {
