@@ -1,4 +1,4 @@
-/* $Id: playcampaign.cpp 16161 2007-03-06 21:53:18Z jhinrichs $ */
+/* $Id: playcampaign.cpp 16732 2007-04-10 17:54:07Z jhinrichs $ */
 /*
    Copyright (C) 2003-2005 by David White <davidnwhite@verizon.net>
    Copyright (C) 2005 by Philippe Plantier <ayin@anathas.org>
@@ -108,6 +108,14 @@ void clean_autosaves(const std::string &label)
 	}
 }
 
+void ask_about_autosaves(display& disp, std::string& label){
+	const int autosave_res = gui::show_dialog(disp, NULL, _("Autosaves"), 
+		_("Do you want to delete the autosaves of this scenario?"), gui::YES_NO);
+	if (autosave_res == 0){
+		clean_autosaves(label);
+	}
+}
+
 LEVEL_RESULT play_game(display& disp, game_state& state, const config& game_config,
 		const game_data& units_data, CVideo& video,
 		upload_log &log,
@@ -230,6 +238,7 @@ LEVEL_RESULT play_game(display& disp, game_state& state, const config& game_conf
 		bool save_game_after_scenario = true;
 
 		const set_random_generator generator_setter(&recorder);
+		LEVEL_RESULT res;
 
 		try {
 			// preserve old label eg. replay
@@ -272,7 +281,6 @@ LEVEL_RESULT play_game(display& disp, game_state& state, const config& game_conf
 
 			sound::play_no_music();
 
-			LEVEL_RESULT res;
 			switch (io_type){
 			case IO_NONE:
 				res = playsingle_scenario(units_data,game_config,scenario,video,state,story,log, skip_replay);
@@ -296,6 +304,8 @@ LEVEL_RESULT play_game(display& disp, game_state& state, const config& game_conf
 				                 _("Defeat"),
 				                 _("You have been defeated!"),
 				                 gui::OK_ONLY);
+				//Make sure the user gets an opportunity to delete his autosaves
+				ask_about_autosaves(disp, state.label);
 			}
 			if(res == QUIT && io_type == IO_SERVER) {
 					config end;
@@ -303,7 +313,7 @@ LEVEL_RESULT play_game(display& disp, game_state& state, const config& game_conf
 					network::send_data(end);
 			}
 			//ask to save a replay of the game
-			if(res == VICTORY || res == DEFEAT) {
+			if(res == VICTORY || res == DEFEAT || res == OBSERVER_END) {
 				const std::string orig_scenario = state.scenario;
 				state.scenario = current_scenario;
 
@@ -404,7 +414,7 @@ LEVEL_RESULT play_game(display& disp, game_state& state, const config& game_conf
 						continue;
 					}
 
-					/*Upadate side info to match current_player info to
+					/*Update side info to match current_player info to
 					  allow it taking the side in next scenario and to be
 					  set in the players list on side server */
 					controller_map::const_iterator ctr = controllers.find(id);
@@ -443,7 +453,16 @@ LEVEL_RESULT play_game(display& disp, game_state& state, const config& game_conf
 
 			//if this isn't the last scenario, then save the game
 			if(save_game_after_scenario) {
-				state.starting_pos = *scenario;
+				//For multiplayer, we want the save to contain the starting position.
+				//For campaings however, this is the start-of-scenario save and the
+				//starting position needs to be empty to force a reload of the scenario
+				//config.
+				if (state.campaign_type == "multiplayer"){
+					state.starting_pos = *scenario;
+				}
+				else{
+					state.starting_pos = config();
+				}
 
 				bool retry = true;
 
@@ -469,9 +488,9 @@ LEVEL_RESULT play_game(display& disp, game_state& state, const config& game_conf
 				}
 			}
 
-			//update the replay start
-			//FIXME: this should only be done if the scenario was not tweaked.
-			//state.starting_pos = *scenario;
+			if (state.campaign_type != "multiplayer"){
+				state.starting_pos = *scenario;
+			}
 		}
 
 		recorder.set_save_info(state);
@@ -482,6 +501,11 @@ LEVEL_RESULT play_game(display& disp, game_state& state, const config& game_conf
 		return QUIT;
 	}
 
+	if (state.campaign_type == "scenario"){
+		//This is the last scenario of the campaign.
+		//Make sure the user gets an opportunity to delete his autosaves
+		ask_about_autosaves(disp, state.label);
+	}
 	return VICTORY;
 }
 
