@@ -1,4 +1,4 @@
-/* $Id: race.hpp 11394 2006-05-10 07:37:51Z rusty $ */
+/* $Id: race.hpp 19010 2007-07-22 13:09:05Z martinxyz $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -46,7 +46,9 @@ private:
 	t_string name_;
 	unsigned int ntraits_;
 	std::vector<std::string> names_[NUM_GENDERS];
+	std::vector<std::string> names_untranslated_[NUM_GENDERS];
 	markov_prefix_map next_[NUM_GENDERS];
+	markov_prefix_map next_untranslated_[NUM_GENDERS];
 	int chain_size_;
 
 	bool not_living_;
