@@ -1,4 +1,4 @@
-/* $Id: random.hpp 7396 2005-07-02 21:37:20Z ott $ */
+/* $Id: random.hpp 8847 2005-11-13 17:11:54Z brunowolff $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Copyright (C) 2005 by Yann Dirson <ydirson@altern.org>
@@ -19,11 +19,6 @@ class config;
 int get_random();
 const config* get_random_results();
 void set_random_results(const config& cfg);
-/** Ensures that the next "random results" operations will not happen on the
- * current random context, eventually adding a dummy random context if
- * necessary.
- */
-void add_random_separator();
 
 class rng
 {
@@ -34,15 +29,13 @@ public:
 	const config* get_random_results();
 	void set_random_results(const config& cfg);
 
-	void add_random_separator();
 protected:
 	config* random();
-	config* set_random(config*);
+	void set_random(config*);
 
 private:
 	config* random_;
-	bool separator_, started_;
-	std::string remaining_values_;
+	size_t random_child_;
 };
 
 struct set_random_generator {
