@@ -1,4 +1,4 @@
-/* $Id: sdl_utils.hpp 9174 2005-12-15 17:33:20Z darthfool $ */
+/* $Id: sdl_utils.hpp 15316 2007-01-21 02:59:29Z sapient $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -164,6 +164,35 @@ struct pixel_data
 	int r, g, b;
 };
 
+struct input_blocker 
+{ 
+	static unsigned instance_count; 
+	input_blocker() 
+	{ 
+		SDL_EventState(SDL_KEYDOWN, SDL_IGNORE); 
+		SDL_EventState(SDL_KEYUP, SDL_IGNORE); 
+		SDL_EventState(SDL_MOUSEBUTTONDOWN, SDL_IGNORE); 
+		SDL_EventState(SDL_MOUSEBUTTONUP, SDL_IGNORE); 
+		SDL_EventState(SDL_JOYBUTTONDOWN, SDL_IGNORE); 
+		SDL_EventState(SDL_JOYBUTTONUP, SDL_IGNORE); 
+		instance_count++; 
+	} 
+	
+	~input_blocker() 
+	{ 
+		instance_count--; 
+		if(instance_count == 0) { 
+			SDL_EventState(SDL_KEYDOWN, SDL_ENABLE); 
+			SDL_EventState(SDL_KEYUP, SDL_ENABLE); 
+			SDL_EventState(SDL_MOUSEBUTTONDOWN, SDL_ENABLE); 
+			SDL_EventState(SDL_MOUSEBUTTONUP, SDL_ENABLE); 
+			SDL_EventState(SDL_JOYBUTTONDOWN, SDL_ENABLE); 
+			SDL_EventState(SDL_JOYBUTTONUP, SDL_ENABLE); 
+		} 
+	} 
+}; 
+
+
 struct surface_lock
 {
 	surface_lock(surface const &surf) : surface_(surf), locked_(false)
