@@ -1,4 +1,4 @@
-/* $Id: binary_or_text.cpp 8861 2005-11-15 22:52:07Z jhinrichs $ */
+/* $Id: binary_or_text.cpp 12583 2006-07-15 04:24:57Z rusty $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Copyright (C) 2005 by Guillaume Melquiond <guillaume.melquiond@gmail.com>
@@ -12,7 +12,7 @@
    See the COPYING file for more details.
 */
 
-#include "../global.hpp"
+#include "global.hpp"
 
 #include "config.hpp"
 #include "filesystem.hpp"
