@@ -1,4 +1,4 @@
-/* $Id: server.cpp 14083 2006-10-26 15:07:17Z edb $ */
+/* $Id: server.cpp 20862 2007-10-02 20:13:57Z mordante $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -77,10 +77,12 @@ config construct_server_message(const std::string& message, const game& g)
 
 void truncate_message(t_string& str)
 {
-	const size_t max_message_length = 240;
-	std::string newstr = str.str();
-	newstr.resize(minimum<size_t>(str.size(),max_message_length));
-	str = newstr;
+	const size_t max_message_length = 256;
+	// The string send can contain utf-8 so truncate as wide_string otherwise
+	// an corrupted utf-8 string can be returned.
+	wide_string newstr = utils::string_to_wstring(str.str());
+	newstr.resize(minimum<size_t>(newstr.size(), max_message_length));
+	str = utils::wstring_to_string(newstr);
 }
 
 }
@@ -181,7 +183,7 @@ server::server(int port, input_stream& input, const config& cfg, size_t nthreads
 			accepted_versions_.insert(*i);
 		}
 	} else {
-		accepted_versions_.insert(game_config::version);
+		accepted_versions_.insert("1.2*");
 	}
 
 	const config::child_list& redirects = cfg_.get_children("redirect");
@@ -218,12 +220,12 @@ bool server::ip_exceeds_connection_limit(const std::string& ip)
 bool server::is_ip_banned(const std::string& ip)
 {
 	for(std::vector<std::string>::const_iterator i = bans_.begin(); i != bans_.end(); ++i) {
-		std::cerr << "comparing for ban '" << *i << "' vs '" << ip << "'\n";
+		LOG_SERVER << "comparing for ban '" << *i << "' vs '" << ip << "'\n";
 		if(utils::wildcard_string_match(ip,*i)) {
-			std::cerr << "is banned\n";
+			std::cerr << ip << " is banned\n";
 			return true;
 		}
-		std::cerr << "not banned\n";
+		LOG_SERVER << "not banned\n";
 	}
 
 	return false;
@@ -251,8 +253,9 @@ void server::dump_stats()
 
 	std::cout <<
 		"Statistics\n"
-		"\tnum_players = " << players_.size() << "\n"
-		"\tlobby_players = " << lobby_players_.nplayers() << "\n"
+		"\tnumber_of_games = " << games_.size() << "\n"
+		"\tnumber_of_players = " << players_.size() << "\n"
+		"\tlobby_players = " << lobby_players_.nobservers() << "\n"
 		"\tstart_interval = " << old_stats << "\n"
 		"\tend_interval = " << last_stats_ << std::endl;
 }
@@ -406,7 +409,7 @@ void server::run()
 					network::disconnect(sock);
 				} else if(ip_exceeds_connection_limit(ip)) {
 					std::cerr << "rejected ip '" << ip << "' due to excessive connections\n";
-					network::send_data(construct_error("Too many connections from your host."),sock);
+					network::send_data(construct_error("Too many connections from your IP."),sock);
 					network::disconnect(sock);
 				} else {
 					network::send_data(version_query_response_,sock);
@@ -427,7 +430,7 @@ void server::run()
 				std::cerr << "fatal network error: " << e.message << "\n";
 				break;
 			} else {
-				std::cerr << "socket closed: " << e.message << "\n";
+				LOG_SERVER << "socket closed: " << e.message << "\n";
 
 				const std::map<network::connection,player>::iterator pl_it = players_.find(e.socket);
 				const std::string pl_name = pl_it != players_.end() ? pl_it->second.name() : "";
@@ -438,12 +441,14 @@ void server::run()
 						initial_response_.remove_child("user",index);
 
 					players_.erase(pl_it);
+					std::cerr << "'" << pl_name << "' (" << network::ip_address(e.socket) << ") has logged off\n";
 				}
 
 				not_logged_in_.remove_player(e.socket);
 				lobby_players_.remove_player(e.socket);
 				for(std::vector<game>::iterator i = games_.begin(); i != games_.end(); ++i) {
 					if(i->is_needed(e.socket)) {
+						//FIXME: when the host disconnects a new one should be chosen and the game shouldn't end (see the handling of [leave_game])
 						delete_game(i);
 						e.socket = 0;
 						break;
@@ -491,6 +496,7 @@ void server::run()
 
 							//now sync players in the lobby again, to remove the game
 							lobby_players_.send_data(sync_initial_response());
+							break;
 						}
 					}
 				}
@@ -504,7 +510,7 @@ void server::run()
 
 				sync_scheduled = true;
 
-				std::cerr << "done closing socket...\n";
+				LOG_SERVER << "done closing socket...\n";
 			}
 
 			continue;
@@ -614,11 +620,11 @@ void server::process_login(const network::connection sock, const config& data)
 		return;
 	}
 
-	//check the username is valid (all alpha-numeric or space (but no space at ends))
+	//check if the username is valid (all alpha-numeric plus underscore)
 	std::string username = (*login)["username"];
 	if(!utils::isvalid_username(username)) {
 		network::send_data(construct_error(
-		                   "This username is not valid"),sock);
+		                   "This username contains invalid characters. Only alpha-numeric characters and underscores are allowed."),sock);
 		return;
 	}
 
@@ -690,24 +696,24 @@ void server::process_query(const network::connection sock, const config& query)
 	} else if(admin_passwd_.empty() == false && query["type"] == admin_passwd_) {
 		admins_.insert(sock);
 		response << "You are now recognized as an administrator";
-		std::cerr << "New Admin recognized:\n";
-		std::cerr << "\tIP: "<< network::ip_address(sock)<<"\n";
+		std::cerr << "New Admin recognized:";
+		std::cerr << "\tIP: "<< network::ip_address(sock);
 		std::map<network::connection, player>::iterator temp = players_.find(sock);
-		std::cerr << "\tnick: "<< temp->second.name()<<"\n";
+		std::cerr << "\tnick: "<< temp->second.name();
 		std::cerr << std::endl;
 	} else if(admins_.count(sock) != 0) {
 		response << process_command(query["type"]);
-		std::cerr << "Admin Command:\n";
-		std::cerr << "\ttype:" << query["type"]<<"\n";
-		std::cerr << "\tIP: "<< network::ip_address(sock)<<"\n";
+		std::cerr << "Admin Command:";
+		std::cerr << "\ttype: " << query["type"];
+		std::cerr << "\tIP: "<< network::ip_address(sock);
 		std::map<network::connection, player>::iterator temp = players_.find(sock);
-		std::cerr << "\tnick: "<< temp->second.name()<<"\n";
+		std::cerr << "\tnick: "<< temp->second.name();
 		std::cerr << std::endl;
 	} else if(admin_passwd_.empty() == false) {
-	  std::cerr << "FAILED Admin attempt:\n";
-	  std::cerr << "\tIP: "<< network::ip_address(sock)<<"\n";
+	  std::cerr << "FAILED Admin attempt:";
+	  std::cerr << "\tIP: "<< network::ip_address(sock);
 	  std::map<network::connection, player>::iterator temp = players_.find(sock);
-	  std::cerr << "\tnick: "<< temp->second.name()<<"\n";
+	  std::cerr << "\tnick: "<< temp->second.name();
 	  std::cerr << std::endl;
 	  response << "Error: unrecognized query";
 	} else {
@@ -772,7 +778,7 @@ void server::process_data_from_player_in_lobby(const network::connection sock, c
 
 	const player_map::iterator pl = players_.find(sock);
 	if(pl == players_.end()) {
-		std::cerr << "ERROR: Could not find player in map\n";
+		LOG_SERVER << "ERROR: Could not find player in map\n";
 	}
 
 	if(create_game != NULL) {
@@ -817,7 +823,7 @@ void server::process_data_from_player_in_lobby(const network::connection sock, c
 			cfg.add_child("leave_game");
 			network::send_data(cfg,sock);
 
-			std::cerr << "attempt to join unknown game\n";
+			LOG_SERVER << "attempt to join unknown game\n";
 			return;
 		}
 
@@ -840,7 +846,7 @@ void server::process_data_from_player_in_lobby(const network::connection sock, c
 
 			lobby_players_.send_data(sync_initial_response());
 		} else {
-			std::cerr << "ERROR: Could not find player in map\n";
+			LOG_SERVER << "ERROR: Could not find player in map\n";
 		}
 	}
 
@@ -887,7 +893,7 @@ void server::process_data_from_player_in_game(const network::connection sock, co
 	}
 
 	if(g == games_.end()) {
-		std::cerr << "ERROR: unknown socket " << games_.size() << "\n";
+		LOG_SERVER << "ERROR: unknown socket " << games_.size() << "\n";
 		return;
 	}
 
@@ -982,7 +988,7 @@ void server::process_data_from_player_in_game(const network::connection sock, co
 	//if the owner is banning someone from the game
 	if(g->is_owner(sock) && (data.child("ban") != NULL || data.child("kick") != NULL)) {
 		std::string name;
-		bool ban = false;;
+		bool ban = false;
 		if (data.child("ban") != NULL) {
 			const config& u = *data.child("ban");
 			name = u["username"];
@@ -990,7 +996,6 @@ void server::process_data_from_player_in_game(const network::connection sock, co
 		} else if (data.child("kick") != NULL) {
 			const config& u = *data.child("kick");
 			name = u["username"];
-			std::cerr << "kick: " << u["username"] << "\n";
 			ban = false;
 		}
 
@@ -1002,17 +1007,21 @@ void server::process_data_from_player_in_game(const network::connection sock, co
 		}
 
 		if(pl->first != sock && pl != players_.end()) {
+			std::string owner = g->find_player(sock)->name();
 			if (ban) {
-				g->ban_player(pl->first);
 				const config& msg = construct_server_message("You have been banned",*g);
 				network::send_data(msg, pl->first);
-
 				const config& p_msg = construct_server_message(pl->second.name() + " has been banned",*g);
 				g->send_data(p_msg);
+				g->ban_player(pl->first);
+				std::cerr << owner << " banned: " << name << " from game: " << g->id() << "\n";
 			} else {
+				const config& msg = construct_server_message("You have been kicked",*g);
+				network::send_data(msg, pl->first);
 				const config& p_msg = construct_server_message(pl->second.name() + " has been kicked",*g);
 				g->send_data(p_msg);
 				g->remove_player(pl->first);
+				std::cerr << owner << " kicked: " << name << " from game: " << g->id() << "\n";
 			}
 
 			config leave_game;
@@ -1032,12 +1041,16 @@ void server::process_data_from_player_in_game(const network::connection sock, co
 			lobby_players_.send_data(sync_initial_response(),sock);
 		} else if(pl == players_.end()) {
 			const config& response = construct_server_message(
-			             "Ban failed: user '" + name + "' not found",*g);
+			             "Kick/ban failed: user '" + name + "' not found",*g);
 			network::send_data(response,sock);
 		}
 	} else if(data.child("ban")) {
 		const config& response = construct_server_message(
-		             "You cannot ban: not the game creator",*g);
+		             "You cannot ban: not the game host",*g);
+		network::send_data(response,sock);
+	} else if(data.child("kick")) {
+		const config& response = construct_server_message(
+		             "You cannot kick: not the game host",*g);
 		network::send_data(response,sock);
 	}
 
@@ -1135,7 +1148,7 @@ void server::process_data_from_player_in_game(const network::connection sock, co
 		const bool res = g->take_side(sock,data);
 		config response;
 		if(res) {
-			std::cerr << "player joined side\n";
+			LOG_SERVER << "player joined side\n";
 			response["side_secured"] = side->second;
 
 			//update the number of available slots
@@ -1215,7 +1228,7 @@ void server::process_data_from_player_in_game(const network::connection sock, co
 				const config& msg = construct_server_message(pl->second.name() + " has left the game",*g);
 				g->send_data(msg);
 			} else {
-				std::cerr << "ERROR: Could not find player in map\n";
+				LOG_SERVER << "ERROR: Could not find player in map\n";
 			}
 
 			if (needed){
@@ -1232,7 +1245,7 @@ void server::process_data_from_player_in_game(const network::connection sock, co
 		if(pl != players_.end()) {
 			pl->second.mark_available(true,"");
 		} else {
-			std::cerr << "ERROR: Could not find player in map\n";
+			LOG_SERVER << "ERROR: Could not find player in map\n";
 		}
 		lobby_players_.add_player(sock);
 
@@ -1246,7 +1259,7 @@ void server::process_data_from_player_in_game(const network::connection sock, co
 	} else if(data["side_secured"].empty() == false) {
 		return;
 	} else if(data["failed"].empty() == false) {
-		std::cerr << "ERROR: failure to get side\n";
+		LOG_SERVER << "ERROR: Failure to get side\n";
 		return;
 	}
 
