@@ -1,4 +1,4 @@
-/* $Id: show_dialog.hpp 11643 2006-05-25 23:04:34Z sapient $ */
+/* $Id: show_dialog.hpp 18010 2007-06-02 08:27:01Z sapient $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -83,7 +83,7 @@ class dialog_button_action
 public:
 	virtual ~dialog_button_action() {}
 
-	enum RESULT { DELETE_ITEM, NO_EFFECT, CLOSE_DIALOG };
+	enum RESULT { DELETE_ITEM, NO_EFFECT, CLOSE_DIALOG, SAVE_TEXT };
 
 	virtual RESULT button_pressed(int menu_selection) = 0;
 };
