@@ -1,4 +1,4 @@
-/* $Id: statistics.cpp 7533 2005-07-20 08:22:37Z ott $ */
+/* $Id: statistics.cpp 12583 2006-07-15 04:24:57Z rusty $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -84,7 +84,7 @@ config write_str_int_map(const stats::str_int_map& m)
 	config res;
 	for(stats::str_int_map::const_iterator i = m.begin(); i != m.end(); ++i) {
 		char buf[50];
-		sprintf(buf,"%d",i->second);
+		snprintf(buf,sizeof(buf),"%d",i->second);
 		res[i->first] = buf;
 	}
 
@@ -109,7 +109,7 @@ config write_battle_result_map(const stats::battle_result_map& m)
 		new_cfg = write_str_int_map(i->second);
 
 		char buf[50];
-		sprintf(buf,"%d",i->first);
+		snprintf(buf,sizeof(buf),"%d",i->first);
 		new_cfg["_num"] = buf;
 	}
 
@@ -188,22 +188,22 @@ config stats::write() const
 	res.add_child("defends",write_battle_result_map(defends));
 
 	char buf[50];
-	sprintf(buf,"%d",recruit_cost);
+	snprintf(buf,sizeof(buf),"%d",recruit_cost);
 	res["recruit_cost"] = buf;
 
-	sprintf(buf,"%d",recall_cost);
+	snprintf(buf,sizeof(buf),"%d",recall_cost);
 	res["recall_cost"] = buf;
 
-	sprintf(buf,"%d",damage_inflicted);
+	snprintf(buf,sizeof(buf),"%d",damage_inflicted);
 	res["damage_inflicted"] = buf;
 
-	sprintf(buf,"%d",damage_taken);
+	snprintf(buf,sizeof(buf),"%d",damage_taken);
 	res["damage_taken"] = buf;
 
-	sprintf(buf,"%d",expected_damage_inflicted);
+	snprintf(buf,sizeof(buf),"%d",expected_damage_inflicted);
 	res["expected_damage_inflicted"] = buf;
 
-	sprintf(buf,"%d",expected_damage_taken);
+	snprintf(buf,sizeof(buf),"%d",expected_damage_taken);
 	res["expected_damage_taken"] = buf;
 
 	return res;
@@ -268,9 +268,10 @@ scenario_context::~scenario_context()
 	mid_scenario = false;
 }
 
-attack_context::attack_context(const unit& a, const unit& d, const battle_stats& stats)
-   : attacker_type(a.type().id()), defender_type(d.type().id()),
-     bat_stats(stats), attacker_side(a.side()), defender_side(d.side())
+attack_context::attack_context(const unit& a, const unit& d, int a_cth, int d_cth)
+   : attacker_type(a.id()), defender_type(d.id()),
+     attacker_side(a.side()), defender_side(d.side()),
+     chance_to_hit_defender(a_cth), chance_to_hit_attacker(d_cth)
 {
 }
 
@@ -282,8 +283,8 @@ attack_context::~attack_context()
 	std::string attacker_key = "s" + attacker_res;
 	std::string defender_key = "s" + defender_res;
 
-	attacker_stats().attacks[bat_stats.chance_to_hit_defender][attacker_key]++;
-	defender_stats().defends[bat_stats.chance_to_hit_attacker][defender_key]++;
+	attacker_stats().attacks[chance_to_hit_defender][attacker_key]++;
+	defender_stats().defends[chance_to_hit_attacker][defender_key]++;
 }
 
 stats& attack_context::attacker_stats()
@@ -296,7 +297,7 @@ stats& attack_context::defender_stats()
 	return get_stats(defender_side);
 }
 
-void attack_context::attack_result(attack_context::ATTACK_RESULT res)
+void attack_context::attack_result(attack_context::ATTACK_RESULT res, int damage)
 {
 	if(stats_disabled > 0)
 		return;
@@ -304,13 +305,11 @@ void attack_context::attack_result(attack_context::ATTACK_RESULT res)
 	push_back(attacker_res,(res == MISSES ? '0' : '1'));
 
 	if(res != MISSES) {
-		attacker_stats().damage_inflicted += bat_stats.damage_defender_takes;
-		defender_stats().damage_taken += bat_stats.damage_defender_takes;
+		attacker_stats().damage_inflicted += damage;
+		defender_stats().damage_taken += damage;
 	}
-	attacker_stats().expected_damage_inflicted +=
-		bat_stats.damage_defender_takes * bat_stats.chance_to_hit_defender;
-	defender_stats().expected_damage_taken +=
-		bat_stats.damage_defender_takes * bat_stats.chance_to_hit_defender;
+	attacker_stats().expected_damage_inflicted += damage * chance_to_hit_defender;
+	defender_stats().expected_damage_taken += damage * chance_to_hit_defender;
 
 	if(res == KILLS) {
 		attacker_stats().killed[defender_type]++;
@@ -318,7 +317,7 @@ void attack_context::attack_result(attack_context::ATTACK_RESULT res)
 	}
 }
 
-void attack_context::defend_result(attack_context::ATTACK_RESULT res)
+void attack_context::defend_result(attack_context::ATTACK_RESULT res, int damage)
 {
 	if(stats_disabled > 0)
 		return;
@@ -326,13 +325,11 @@ void attack_context::defend_result(attack_context::ATTACK_RESULT res)
 	push_back(defender_res,(res == MISSES ? '0' : '1'));
 
 	if(res != MISSES) {
-		attacker_stats().damage_taken += bat_stats.damage_attacker_takes;
-		defender_stats().damage_inflicted += bat_stats.damage_attacker_takes;
+		attacker_stats().damage_taken += damage;
+		defender_stats().damage_inflicted += damage;
 	}
-	attacker_stats().expected_damage_taken +=
-		bat_stats.damage_attacker_takes * bat_stats.chance_to_hit_attacker;
-	defender_stats().expected_damage_inflicted +=
-		bat_stats.damage_attacker_takes * bat_stats.chance_to_hit_attacker;
+	attacker_stats().expected_damage_taken += damage * chance_to_hit_attacker;
+	defender_stats().expected_damage_inflicted += damage * chance_to_hit_attacker;
 
 	if(res == KILLS) {
 		attacker_stats().deaths[attacker_type]++;
@@ -346,8 +343,8 @@ void recruit_unit(const unit& u)
 		return;
 
 	stats& s = get_stats(u.side());
-	s.recruits[u.type().id()]++;
-	s.recruit_cost += u.type().cost();
+	s.recruits[u.id()]++;
+	s.recruit_cost += u.cost();
 }
 
 void recall_unit(const unit& u)
@@ -356,8 +353,8 @@ void recall_unit(const unit& u)
 		return;
 
 	stats& s = get_stats(u.side());
-	s.recalls[u.type().id()]++;
-	s.recall_cost += u.type().cost();
+	s.recalls[u.id()]++;
+	s.recall_cost += u.cost();
 }
 
 void un_recall_unit(const unit& u)
@@ -366,17 +363,28 @@ void un_recall_unit(const unit& u)
 		return;
 
 	stats& s = get_stats(u.side());
-	s.recalls[u.type().id()]--;
-	s.recall_cost -= u.type().cost();
+	s.recalls[u.id()]--;
+	s.recall_cost -= u.cost();
 }
 
+void un_recruit_unit(const unit& u)
+{
+	if(stats_disabled > 0)
+		return;
+
+	stats& s = get_stats(u.side());
+	s.recruits[u.type().id()]--;
+	s.recruit_cost -= u.type().cost();
+}
+
+
 void advance_unit(const unit& u)
 {
 	if(stats_disabled > 0)
 		return;
 
 	stats& s = get_stats(u.side());
-	s.advanced_to[u.type().id()]++;
+	s.advanced_to[u.id()]++;
 }
 
 std::vector<std::string> get_categories()
