@@ -1,4 +1,4 @@
-/* $Id: titlescreen.cpp 7533 2005-07-20 08:22:37Z ott $ */
+/* $Id: titlescreen.cpp 12051 2006-06-12 02:20:11Z sapient $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -18,13 +18,13 @@
 #include "display.hpp"
 #include "events.hpp"
 #include "filesystem.hpp"
-#include "font.hpp"
 #include "game_config.hpp"
 #include "hotkeys.hpp"
 #include "key.hpp"
 #include "gettext.hpp"
 #include "log.hpp"
-#include "preferences.hpp"
+#include "marked-up_text.hpp"
+#include "preferences_display.hpp"
 #include "sdl_utils.hpp"
 #include "show_dialog.hpp"
 #include "titlescreen.hpp"
@@ -33,7 +33,7 @@
 #include "serialization/parser.hpp"
 #include "serialization/preprocessor.hpp"
 
-#include "SDL_ttf.h"
+#include "sdl_ttf/SDL_ttf.h"
 
 #define LOG_DP LOG_STREAM(info, display)
 #define ERR_DP LOG_STREAM(err, display)
@@ -83,7 +83,7 @@ bool fade_logo(display& screen, int xpos, int ypos)
 
 			screen.update_display();
 
-			SDL_Delay(10);
+			screen.delay(10);
 
 			events::pump();
 			if(screen.video().modeChanged()) {
@@ -149,6 +149,60 @@ const config get_tips_of_day()
 	return cfg;
 }
 
+
+
+void draw_tip_of_day(display& screen, config& tips_of_day, int* ntip, const std::string& style, gui::button* const next_tip_button, gui::button* const help_tip_button, const SDL_Rect* const main_dialog_area, surface_restorer& tip_of_day_restorer)
+{
+
+    // Restore the previous tip of day area to its old state (section of the title image).
+    tip_of_day_restorer.restore();
+
+    // Draw tip of the day
+    std::string tip_of_day = get_tip_of_day(tips_of_day,ntip);
+    if(tip_of_day.empty() == false) {
+        tip_of_day = font::word_wrap_text(tip_of_day,font::SIZE_NORMAL,
+                                          (game_config::title_tip_width*screen.x())/1024);
+
+        const std::string& tome = font::word_wrap_text(_("-- The Tome of Wesnoth"),
+                font::SIZE_NORMAL,
+                (game_config::title_tip_width*screen.x())/1024);
+
+        const int pad = game_config::title_tip_padding;
+
+        SDL_Rect area = font::text_area(tip_of_day,font::SIZE_NORMAL);
+        SDL_Rect tome_area = font::text_area(tome,font::SIZE_NORMAL,TTF_STYLE_ITALIC);
+        area.w = maximum<size_t>(area.w,tome_area.w) + 2*pad;
+        area.h += tome_area.h + next_tip_button->location().h + 3*pad;
+
+        area.x = main_dialog_area->x - (game_config::title_tip_x*screen.x())/1024 - area.w;
+        area.y = main_dialog_area->y + main_dialog_area->h - area.h;
+
+        // Note: The buttons' locations need to be set before the dialog frame is drawn.
+        // Otherwise, when the buttons restore their area, they draw parts
+        // of the old dialog frame at their old locations.
+        // This way, the buttons draw a part of the title image, because the call to restore
+        // above restored the old tip of the day area to its initial state (the title image).
+        next_tip_button->set_location(area.x + area.w - next_tip_button->location().w - pad,
+                                      area.y + area.h - pad - next_tip_button->location().h);
+
+        help_tip_button->set_location(area.x + pad,
+                                      area.y + area.h - pad - next_tip_button->location().h);
+		help_tip_button->set_dirty(); //force redraw even if location did not change.
+        gui::draw_dialog_frame(area.x,area.y,area.w,area.h,screen.video(),&style, &tip_of_day_restorer);
+
+
+
+
+        font::draw_text(&screen.video(), area, font::SIZE_NORMAL, font::NORMAL_COLOUR,
+                         tip_of_day, area.x + pad, area.y + pad);
+        font::draw_text(&screen.video(), area, font::SIZE_NORMAL, font::NORMAL_COLOUR,
+                         tome, area.x + area.w - tome_area.w - pad,
+                         next_tip_button->location().y - tome_area.h - pad, false, TTF_STYLE_ITALIC);
+    }
+
+    LOG_DP << "drew tip of day\n";
+}
+
 } //end anonymous namespace
 
 namespace gui {
@@ -201,14 +255,16 @@ TITLE_RESULT show_title(display& screen, config& tips_of_day, int* ntip)
 					       N_("TitleScreen button^Campaign"),
 					       N_("TitleScreen button^Multiplayer"),
 					       N_("TitleScreen button^Load"),
+					       N_("TitleScreen button^Get Add-ons"),
 					       N_("TitleScreen button^Language"),
 					       N_("TitleScreen button^Preferences"),
 					       N_("About"),
-					       N_("TitleScreen button^Quit") };
+						   N_("TitleScreen button^Quit") };
 	static const char* help_button_labels[] = { N_("Start a tutorial to familiarize yourself with the game"),
 						    N_("Start a new single player campaign"),
 						    N_("Play multiplayer (hotseat, LAN, or Internet), or a single scenario against the AI"),
 						    N_("Load a single player saved game"),
+						    N_("Download usermade campaigns, eras, or map packs"),
 						    N_("Change the language"),
 						    N_("Configure the game's settings"),
 						    N_("View the credits"),
@@ -222,7 +278,7 @@ TITLE_RESULT show_title(display& screen, config& tips_of_day, int* ntip)
 #ifdef USE_TINY_GUI
 	const int menu_yincr = 15;
 #else
-	const int menu_yincr = 40;
+	const int menu_yincr = 35;
 #endif
 	const int padding = game_config::title_buttons_padding;
 
@@ -235,7 +291,8 @@ TITLE_RESULT show_title(display& screen, config& tips_of_day, int* ntip)
 	}
 
 	SDL_Rect main_dialog_area = {menu_xbase-padding,menu_ybase-padding,max_width+padding*2,menu_yincr*(nbuttons-1)+buttons.back().height()+padding*2};
-	std::string style = "mainmenu";
+
+    const std::string style = "mainmenu";
 	draw_dialog_frame(main_dialog_area.x,main_dialog_area.y,main_dialog_area.w,main_dialog_area.h,screen.video(),&style);
 
 	for(b = 0; b != nbuttons; ++b) {
@@ -244,40 +301,23 @@ TITLE_RESULT show_title(display& screen, config& tips_of_day, int* ntip)
 	}
 
 	gui::button next_tip_button(screen.video(),_("More"),button::TYPE_PRESS,"lite_small");
+	gui::button help_tip_button(screen.video(),_("Help"),button::TYPE_PRESS,"lite_small");
+	// FIXME: Translatable string is here because we WILL put text in before 1.2!
+	gui::button beg_button(screen.video(),("Help Wesnoth"),button::TYPE_IMAGE,"menu-button",button::MINIMUM_SPACE);
+	beg_button.set_help_string(_("Help Wesnoth by sending us information"));
 
 	if(tips_of_day.empty()) {
 		tips_of_day = get_tips_of_day();
 	}
-	std::string tip_of_day = get_tip_of_day(tips_of_day,ntip);
-	if(tip_of_day.empty() == false) {
-		tip_of_day = font::word_wrap_text(tip_of_day,font::SIZE_NORMAL,
-						  (game_config::title_tip_width*screen.x())/1024);
 
-		const std::string& tome = font::word_wrap_text(_("-- The Tome of Wesnoth"),
-							       font::SIZE_NORMAL,
-							       (game_config::title_tip_width*screen.x())/1024);
 
-		const int pad = game_config::title_tip_padding;
+	surface_restorer tip_of_day_restorer;
 
-		SDL_Rect area = font::text_area(tip_of_day,font::SIZE_NORMAL);
-		SDL_Rect tome_area = font::text_area(tome,font::SIZE_NORMAL,TTF_STYLE_ITALIC);
-		area.w = maximum<size_t>(area.w,tome_area.w) + 2*pad;
-		area.h += tome_area.h + next_tip_button.location().h + 3*pad;
+	draw_tip_of_day(screen, tips_of_day, ntip, style, &next_tip_button, &help_tip_button, &main_dialog_area, tip_of_day_restorer);
 
-		area.x = main_dialog_area.x - (game_config::title_tip_x*screen.x())/1024 - area.w;
-		area.y = main_dialog_area.y + main_dialog_area.h - area.h;
-
-		draw_dialog_frame(area.x,area.y,area.w,area.h,screen.video(),&style);
-
-		next_tip_button.set_location(area.x + area.w - next_tip_button.location().w - pad,
-		                             area.y + area.h - pad - next_tip_button.location().h);
-
-		font::draw_text(&screen.video(), area, font::SIZE_NORMAL, font::NORMAL_COLOUR,
-		                tip_of_day, area.x + pad, area.y + pad);
-		font::draw_text(&screen.video(), area, font::SIZE_NORMAL, font::NORMAL_COLOUR,
-		                tome, area.x + area.w - tome_area.w - pad,
-		                next_tip_button.location().y - tome_area.h - pad, false, TTF_STYLE_ITALIC);
-	}
+	const int pad = game_config::title_tip_padding;
+	beg_button.set_location(screen.x() - pad - beg_button.location().w,
+		screen.y() - pad - beg_button.location().h);
 
 	events::raise_draw_event();
 
@@ -303,7 +343,15 @@ TITLE_RESULT show_title(display& screen, config& tips_of_day, int* ntip)
 				*ntip = *ntip + 1;
 			}
 
-			return TITLE_CONTINUE;
+            draw_tip_of_day(screen, tips_of_day, ntip, style, &next_tip_button, &help_tip_button, &main_dialog_area, tip_of_day_restorer);
+		}
+
+		if(help_tip_button.pressed()) {
+			return SHOW_HELP;
+		}
+
+		if(beg_button.pressed()) {
+			return BEG_FOR_UPLOAD;
 		}
 
 		events::raise_process_event();
@@ -324,7 +372,7 @@ TITLE_RESULT show_title(display& screen, config& tips_of_day, int* ntip)
 			return TITLE_CONTINUE;
 		}
 
-		SDL_Delay(20);
+		screen.delay(20);
 	}
 
 	return QUIT_GAME;
