@@ -1,6 +1,20 @@
+/* $Id: tooltips.cpp 8657 2005-10-28 21:03:07Z ydirson $ */
+/*
+   Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
+   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY.
+
+   See the COPYING file for more details.
+*/
+
 #include "global.hpp"
 
 #include "font.hpp"
+#include "marked-up_text.hpp"
 #include "sdl_utils.hpp"
 #include "tooltips.hpp"
 #include "video.hpp"
@@ -113,11 +127,11 @@ void clear_tooltips()
 
 void clear_tooltips(const SDL_Rect& rect)
 {
-	clear_tooltip();
 	for(std::vector<tooltip>::iterator i = tips.begin(); i != tips.end(); ) {
 		if(rectangles_overlap(i->rect,rect)) {
 			i = tips.erase(i);
 			current_tooltip = tips.end();
+			clear_tooltip();
 		} else {
 			++i;
 		}
