@@ -1,4 +1,4 @@
-/* $Id: scrollarea.cpp 8173 2005-09-06 14:00:05Z ott $*/
+/* $Id: scrollarea.cpp 9409 2006-01-03 20:04:50Z jhinrichs $*/
 /*
    Copyright (C) 2004 by Guillaume Melquiond <guillaume.melquiond@gmail.com>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -11,9 +11,9 @@
    See the COPYING file for more details.
 */
 
-#include "../global.hpp"
+#include "global.hpp"
 
-#include "scrollarea.hpp"
+#include "widgets/scrollarea.hpp"
 
 #include <algorithm>
 #include <iostream>
