@@ -1,4 +1,4 @@
-/* $Id: slider.hpp 14951 2006-12-31 16:19:24Z edb $ */
+/* $Id: slider.hpp 15250 2007-01-15 22:42:52Z soliton $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -47,7 +47,7 @@ public:
 	virtual void set_location(SDL_Rect const &rect);
 
 protected:
-	bool requires_event_focus() const { return enabled(); }
+	bool requires_event_focus(const SDL_Event *event=NULL) const;
 	virtual void handle_event(const SDL_Event& event);
 	virtual void draw_contents();
 
