@@ -1,4 +1,4 @@
-/* $Id: widget.cpp 13460 2006-09-08 08:49:00Z dirus $ */
+/* $Id: widget.cpp 15989 2007-02-21 21:13:25Z mordante $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -22,21 +22,21 @@ namespace {
 
 namespace gui {
 
-widget::widget(const widget &o)
-	: events::handler(), video_(o.video_), restorer_(o.restorer_),
-	  rect_(o.rect_), focus_(o.focus_), needs_restore_(o.needs_restore_),
+	widget::widget(const widget &o)
+	: events::handler(), focus_(o.focus_), video_(o.video_), restorer_(o.restorer_),
+	  rect_(o.rect_), needs_restore_(o.needs_restore_),
 	  state_(o.state_), hidden_override_(o.hidden_override_),
 	  enabled_(o.enabled_), clip_(o.clip_), clip_rect_(o.clip_rect_),
 	  volatile_(o.volatile_), help_text_(o.help_text_),
-	  help_string_(o.help_string_), align_(o.align_)
+	  help_string_(o.help_string_), align_(o.align_), id_(o.id_)
 {
 }
 
 widget::widget(CVideo& video, bool auto_join)
-	: handler(auto_join), video_(&video), rect_(EmptyRect), focus_(true),
+	: handler(auto_join), focus_(true), video_(&video), rect_(EmptyRect), 
 	  needs_restore_(false), state_(UNINIT), hidden_override_(false),
-	  enabled_(true), clip_(false), volatile_(false), help_string_(0),
-	  align_(RIGHT_ALIGN)
+	  enabled_(true), clip_(false), clip_rect_(EmptyRect), volatile_(false),
+	  help_string_(0), align_(RIGHT_ALIGN)
 {
 }
 
@@ -139,9 +139,9 @@ void widget::set_focus(bool focus)
 	set_dirty(true);
 }
 
-bool widget::focus() const
+bool widget::focus(const SDL_Event* event)
 {
-	return events::has_focus(this) && focus_;
+	return events::has_focus(this, event) && focus_;
 }
 
 void widget::hide(bool value)
@@ -214,6 +214,18 @@ bool widget::dirty() const
 	return state_ == DIRTY;
 }
 
+const std::string& widget::id() const
+{
+	return id_;
+}
+
+void widget::set_id(const std::string& id)
+{
+	if (id_.empty()){
+		id_ = id;
+	}
+}
+
 void widget::bg_update()
 {
 	for(std::vector< surface_restorer >::iterator i = restorer_.begin(),
