@@ -1,4 +1,4 @@
-/* $Id: widget.hpp 13460 2006-09-08 08:49:00Z dirus $ */
+/* $Id: widget.hpp 15790 2007-02-14 23:55:53Z jhinrichs $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -43,7 +43,8 @@ public:
 	unsigned height() const;
 	ALIGN align() const;
 
-	virtual bool focus() const;
+	//focus() may gain the focus if the currently focused handler doesn't require this event
+	bool focus(const SDL_Event* event);
 	void set_focus(bool focus);
 
 	virtual void hide(bool value = true);
@@ -65,6 +66,8 @@ public:
 
 	void set_dirty(bool dirty=true);
 	bool dirty() const;
+	const std::string& id() const;
+	void set_id(const std::string& id);
 
 	void set_help_string(const std::string& str);
 
@@ -85,14 +88,15 @@ protected:
 
 	CVideo& video() const { return *video_; };
 
-	virtual void handle_event(SDL_Event const &/*event*/) {}
-
 	virtual void draw();
 	virtual void draw_contents() {};
 	virtual void update_location(SDL_Rect const &rect);
 
 	const SDL_Rect* clip_rect() const;
 
+	virtual void handle_event(SDL_Event const &/*event*/) {}
+	bool focus_;		// Should user input be ignored?
+
 private:
 	void volatile_draw();
 	void volatile_undraw();
@@ -102,7 +106,6 @@ private:
 	CVideo* video_;
 	std::vector< surface_restorer > restorer_;
 	SDL_Rect rect_;
-	bool focus_;		// Should user input be ignored?
 	mutable bool needs_restore_; // Have we drawn ourselves, so that if moved, we need to restore the background?
 
 	enum { UNINIT, HIDDEN, DIRTY, DRAWN } state_;
@@ -116,6 +119,7 @@ private:
 	std::string help_text_;
 	int help_string_;
 	ALIGN align_; //limited support, use position
+	std::string id_;
 
 	friend class scrollpane;
 };
